{
 "cells": [
  {
   "cell_type": "markdown",
   "id": "d5f95feb",
   "metadata": {},
   "source": [
    "# Convergence Plots"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "dc1a0c1f",
   "metadata": {},
   "source": [
    "The Convergence Plots consist of two Plotly FigureWidget Subplots, the `plasma_plot` and the `t_inner_luminosities_plot`. The plots are stored in the `convergence_plots` attribute of the simulation object `sim` and can be accessed using `sim.convergence_plots.plasma_plot` and `sim.convergence_plots.t_inner_luminosities_plot`.\n",
    "\n",
    "The Convergence Plots are shown by default when you running TARDIS because `show_convergence_plots` parameter of the `run_tardis()` function is set to `True`. If you don't want to do this, set it to `False`. "
   ]
  },
  {
   "cell_type": "markdown",
   "id": "6db4edf2",
   "metadata": {},
   "source": [
    "<div class=\"alert alert-info\">\n",
    "\n",
    "Note\n",
    "    \n",
    "You only need to include `export_convergence_plots=True` in the `run_tardis` function when you want to share the notebook. The function shows the plot using the Plotly `notebook_connected` renderer, which helps display the plot online. You don't need to do it when running the notebook locally.\n",
    "\n",
    "</div>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "ba7cc7d2",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2021-10-14T16:49:53.480066Z",
     "iopub.status.busy": "2021-10-14T16:49:53.479418Z",
     "iopub.status.idle": "2021-10-14T16:50:54.425224Z",
     "shell.execute_reply": "2021-10-14T16:50:54.434744Z"
    },
    "scrolled": false
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/usr/share/miniconda3/envs/tardis/lib/python3.7/importlib/_bootstrap.py:219: QAWarning: pyne.data is not yet QA compliant.\n",
      "  return f(*args, **kwds)\n"
     ]
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "5899a549ffc84f3381b4e3a747850d17",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Iterations:          0/? [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c28ba22c99ff40baa1019a408a8846c4",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Packets:             0/? [00:00<?, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "[\u001b[1mpy.warnings         \u001b[0m][\u001b[1;33mWARNING\u001b[0m]  /usr/share/miniconda3/envs/tardis/lib/python3.7/site-packages/traitlets/traitlets.py:3050: FutureWarning: --rc={'figure.dpi': 96} for dict-traits is deprecated in traitlets 5.0. You can pass --rc <key=value> ... multiple times to add items to a dict.\n",
      "  FutureWarning,\n",
      " (\u001b[1mwarnings.py\u001b[0m:110)\n"
     ]
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "dc6c9c724d4b413bbf3da367eccae4ba",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "TqdmHBox(children=(HTML(value='Iterations:', layout=Layout(width='6%')), FloatProgress(value=0.0, layout=Layou…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "34b378ff483e4eab8245110161d422a0",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "TqdmHBox(children=(HTML(value='Packets:   ', layout=Layout(width='6%')), FloatProgress(value=0.0, layout=Layou…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "b6da0dc359b94da29613187eb419ea70",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "VBox(children=(FigureWidget({\n",
       "    'data': [{'type': 'scatter', 'uid': '504f384e-5c8c-4ed3-90b7-c5151d60a66b', …"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"aa6510b2-12ea-47ca-ab5d-b292bbbe1bcd\" class=\"plotly-graph-div\" style=\"height:450px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"aa6510b2-12ea-47ca-ab5d-b292bbbe1bcd\")) {                    Plotly.newPlot(                        \"aa6510b2-12ea-47ca-ab5d-b292bbbe1bcd\",                        [{\"type\":\"scatter\",\"uid\":\"504f384e-5c8c-4ed3-90b7-c5151d60a66b\",\"xaxis\":\"x\",\"yaxis\":\"y\"},{\"type\":\"scatter\",\"uid\":\"068368d4-1fde-4244-bfc0-99eb1284ad5f\",\"xaxis\":\"x2\",\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#000080\"},\"name\":\"1\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"ba8521d2-54a3-4005-88c3-728c3acb0a60\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[9926.501965464813,9911.63537753482,9896.813253389762,9882.035393850509,9867.301600925806,9852.611677803428,9837.96542884143,9823.362659559447,9808.803176630105,9794.286787870464,9779.813302233586,9765.382529800137,9750.99428177009,9736.64837045449,9722.344609267282,9708.082812717237,9693.862796399926,9679.684376989773,9665.547372232175,9651.451600935694],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#000080\"},\"name\":\"1\",\"type\":\"scatter\",\"uid\":\"66b148fd-d43c-4f58-b2fa-950ae23e8311\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.40039163797855976,0.33245223097543924,0.2896679818236787,0.2577141002351936,0.23224568138195772,0.211204659222757,0.19341188222536587,0.17811401706296348,0.16479446041469908,0.15308090298851573,0.14269498356756605,0.13342261532969785,0.12509541040763922,0.11757848682757521,0.11076215248105115,0.10455605179542055,0.09888493580965113,0.09368553636653854,0.08890421153628925,0.08449514228457095],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#0000bd\"},\"name\":\"2\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"4a030947-7736-4016-b67e-5406bf87fe0f\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10140.644658439542,10163.140953757294,10199.392781222336,10228.793058184721,10271.14775928106,10224.009713529731,10228.732523936606,10216.98049975123,10217.783033963955,10193.706231603874,10148.77879424612,10080.136790247385,10031.646882137076,10030.254549667037,9988.12702379364,9874.634222100456,9844.474903130327,9776.381862231508,9680.562581778317,9611.593058427065],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#0000bd\"},\"name\":\"2\",\"type\":\"scatter\",\"uid\":\"4e164e36-6f2b-46b7-b07a-6793f37657bb\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5074939829206923,0.39593831162891974,0.32150485888655256,0.26573787630888046,0.2236515966575156,0.19686688849248643,0.1746427953806121,0.15625093331810624,0.13946942342362406,0.12759533918829524,0.11697794966442067,0.10915672831486313,0.10296463647641346,0.09515332126864076,0.08981745405810744,0.08689548233577285,0.08198790793189142,0.07881149990806682,0.07637264409196345,0.07345198061495406],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#0000fa\"},\"name\":\"3\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"c50ce403-4912-4a3a-9fef-788a9f3e4dab\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10821.384716452621,10824.07375074843,10898.794282582267,10931.581728038504,10962.883353030435,10956.472449386303,10935.661811838689,10896.394485335457,10868.778286813804,10846.86064742898,10799.242899977486,10741.078256171444,10679.03654492254,10616.6413627693,10548.485755133186,10483.027318852863,10402.58849317583,10353.528838881304,10280.790364670062,10205.89807450607],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#0000fa\"},\"name\":\"3\",\"type\":\"scatter\",\"uid\":\"baedddde-a639-492d-833a-5150f927b366\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5246621760292516,0.41191697242104813,0.33082428419284166,0.2739415803649503,0.23102276356532733,0.20265771066458735,0.18068103823778522,0.16215467464075065,0.14618948104529478,0.13362668956992607,0.12450448547982709,0.11605105087549335,0.10925211388307239,0.10302987363746915,0.09831778993852412,0.0932577131276202,0.08908435787384879,0.08446805448195224,0.08117712884118686,0.07815148665239906],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#0022ff\"},\"name\":\"4\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"d4dc6e33-8f86-4dbb-964b-f9a2288ba8aa\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11001.634918288773,11064.199689011095,11146.787545057517,11182.280653331733,11189.736123692379,11179.454369423816,11213.79207405269,11157.651049771417,11091.366692176987,11032.681911673413,10951.71311170724,10882.347593647743,10815.56574149097,10758.062388449993,10666.645789560242,10589.476597771141,10519.279070600585,10489.380846260961,10394.331364500693,10280.44535660762],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#0022ff\"},\"name\":\"4\",\"type\":\"scatter\",\"uid\":\"d3185c2c-2d08-4ed8-91fd-a795f4e679c9\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.48255611027402595,0.37531673900188744,0.3008854405436438,0.24970650566435726,0.21504788747697892,0.1889210232599808,0.16485989155704653,0.14922567218546676,0.1373433490366653,0.1270628239280638,0.11816510452204829,0.11046612213518453,0.10408751562676459,0.09837704095780829,0.09380107799147919,0.08948233963910264,0.08532986022143939,0.08049857949608492,0.07819235373949822,0.07599589756382483],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#0057ff\"},\"name\":\"5\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"6c607107-fbba-438b-aa82-fffd10d5cc58\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.69813331972,11131.435799441577,11213.984633035107,11254.938537458936,11264.10756107921,11231.114026250594,11180.234767099426,11161.43757582825,11095.861090734456,11098.458607564848,11036.771405771051,10960.49690639981,10968.575819463373,10890.828989905996,10799.341137335274,10659.853383147958,10549.231623432072,10506.788250185065,10398.595227817385,10289.349894730598],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#0057ff\"},\"name\":\"5\",\"type\":\"scatter\",\"uid\":\"bcec50e9-587c-422f-8e91-5bf985548eda\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46875384769180994,0.3582440793604906,0.2859963458991618,0.23841076673448683,0.20840515079453156,0.18245979900971618,0.1638530282293532,0.14657197302070762,0.13503875104453528,0.12203984302262225,0.11334205862439253,0.10619057923554849,0.09765445785021042,0.09265039020379297,0.08856994824064786,0.0861030166939687,0.08350964472774987,0.07926097434257318,0.07675258324197402,0.07475268831395629],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#008dff\"},\"name\":\"6\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"e4cf7f48-75e7-4659-88cf-4ad307f0b4f5\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11004.024489659887,11119.370907976154,11195.435272777357,11259.07218492983,11285.20780804646,11285.17736284529,11257.669785381573,11225.435571936492,11186.445768225169,11099.126705981142,11029.754124780751,10939.09235294023,10877.977505280129,10799.952863140219,10803.94962659834,10716.294187213076,10608.39027776731,10536.800302652608,10451.345002096903,10351.499433918842],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#008dff\"},\"name\":\"6\",\"type\":\"scatter\",\"uid\":\"1afe8085-1c5e-4fd6-8400-825787989256\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47879511389335816,0.36722911837191247,0.2926208974449371,0.24239288815881765,0.20444578448470932,0.17802906434287452,0.15880728036632202,0.14352699270970695,0.13113431023478964,0.12123492206018885,0.11293848121019129,0.107206115377895,0.09996151019829129,0.09452711171505655,0.08773741567449585,0.0838574125841496,0.08091696481124855,0.07741620755854674,0.07503066951006154,0.0727305286162828],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#00c3ff\"},\"name\":\"7\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"3933263b-fb87-4877-83f4-13e1eb33d34d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11049.228732355552,11156.739354515785,11233.159171838806,11257.86819871853,11259.221213382081,11218.728487793938,11177.383540027478,11170.932602943105,11091.339644892223,11058.83258870618,11086.886472116763,10967.000400044035,10888.705512509965,10859.351173962054,10794.116212447141,10665.940454226306,10614.036765336794,10560.167635600494,10433.600109025549,10347.135454231406],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#00c3ff\"},\"name\":\"7\",\"type\":\"scatter\",\"uid\":\"87526170-889b-4ef0-b6ea-f618c03fcf72\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4697400940159998,0.3588700697047573,0.29077776563828756,0.2443651184699209,0.20776673425141715,0.1852074960564398,0.16487114788798946,0.14711076442391682,0.13525030370898636,0.12403257789506693,0.11208234573021662,0.10708808842987298,0.1008199099410747,0.09351009430956675,0.08797758265708822,0.08557481001143187,0.08167863229931253,0.07764065281949213,0.07578960072572662,0.07324774090303579],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#0ff8e8\"},\"name\":\"8\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"70447eaf-ba12-40e1-8852-cae02c753a46\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11037.08503719401,11149.996498693195,11245.895992066266,11293.021085350518,11348.844546340542,11303.81450750131,11275.886160361555,11193.561854480458,11139.762040353016,11142.50167244028,11052.1571050735,10947.278343765189,10930.67339710046,10870.232618754231,10717.538511627446,10653.978725318402,10563.0762100547,10483.387471111888,10423.15401494719,10305.26962980183],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#0ff8e8\"},\"name\":\"8\",\"type\":\"scatter\",\"uid\":\"9dd9c60f-dc05-4561-9a29-5061120c6962\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46951709287046905,0.3558132377939077,0.28344389342857873,0.23679038121368734,0.2006318674457632,0.17752655689561797,0.15896810063770853,0.14566983788022744,0.13249513450931652,0.11945436911075241,0.11202516442423788,0.10653028310041686,0.09880763358506521,0.09250430944965742,0.0904904576740684,0.08597716733696596,0.08263854439908624,0.07942790299289659,0.07616188750490346,0.07438003691528026],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#3affbc\"},\"name\":\"9\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"d73ca3e5-1ecc-4497-b43c-77e55c0f0906\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11052.295325497007,11212.705361919509,11368.864591182264,11398.78996374572,11425.824065083918,11374.755681704642,11321.373184735603,11274.453385553123,11206.414763213426,11152.830452841748,11103.737908148854,10987.81945397592,10971.696465389161,10850.543109804723,10728.169760230841,10715.360231738356,10614.329903571434,10533.835974010104,10505.237794759547,10368.71936512106],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#3affbc\"},\"name\":\"9\",\"type\":\"scatter\",\"uid\":\"7d9323bd-004e-41e4-9e75-d9148f7c38ff\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47175098459955545,0.3533364312643379,0.27692864002604506,0.23227462876251695,0.1992339273085163,0.1752154543235442,0.15695860796865863,0.1425401542709221,0.12987043769720186,0.1194981244007122,0.11065799714369325,0.10503597469582807,0.09725717606234426,0.09312192856965566,0.08970996968103623,0.0840348909677989,0.08128474934784594,0.07834393294338478,0.0738203172283877,0.07253718289337063],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#66ff91\"},\"name\":\"10\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"bfc49949-0d05-4ed8-a5f8-9a5b07643a36\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11054.591787334148,11225.528282829357,11397.756567710436,11384.015365915013,11451.389274254923,11459.610588977725,11376.050029186565,11274.095516148473,11272.499217755421,11178.085961626613,11140.791754287642,11068.611912757306,11035.291654969596,10948.379622684975,10846.30843479845,10760.164548553728,10717.142639062211,10660.04707328942,10504.059452325992,10393.011181236432],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#66ff91\"},\"name\":\"10\",\"type\":\"scatter\",\"uid\":\"3fdc3a52-e5fd-4de8-8c6f-60857fa88057\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46869175429362847,0.3489553241372833,0.272245622698486,0.23088331103266788,0.19396911644591475,0.16966303737984223,0.15365541714258069,0.14066857846930758,0.12625486648965414,0.11769844507310218,0.10873442822036551,0.10217357366795128,0.09428760780374013,0.08974201060071937,0.08619004289280512,0.08223115714542878,0.07778821666696925,0.07403971132288675,0.07307298001360511,0.07131405537195114],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#91ff66\"},\"name\":\"11\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"915feae1-c564-4fc8-bab5-3ef0392a3b31\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.824129738192,11205.221198116975,11257.276210948365,11249.982124832772,11346.90454878048,11369.200845314623,11327.975637400814,11265.70277970273,11242.69566867425,11125.713354976318,11085.643189312845,11003.766807453341,10952.925463047199,10818.865962225485,10751.827669918477,10622.890289468805,10581.153922616171,10457.765325669847,10406.863293593042,10293.690965995087],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#91ff66\"},\"name\":\"11\",\"type\":\"scatter\",\"uid\":\"92caea74-e76a-45ac-823b-dc1ce46965f3\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4745474662644775,0.35492209696573995,0.2908775211495747,0.24470866481882064,0.20504347418985933,0.17741364784201571,0.158531848563811,0.14501821946430396,0.13008713859723542,0.12233533943053944,0.11238724105660731,0.10569730424606064,0.09826037906138733,0.09469637422940755,0.0899277992037678,0.0877518224215559,0.08291661849234434,0.08063515139722367,0.07697286067066779,0.07517475455159717],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#bcff3a\"},\"name\":\"12\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"4228edf1-0001-48a6-9da5-b12eb5f63e91\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11033.00930341031,11148.879430055598,11221.615762493011,11261.57342812569,11263.081991396044,11194.36101620315,11176.653686173815,11119.362957181675,11160.897203210388,11060.87637020031,11002.1449565465,10869.256977805022,10791.657316178955,10690.963307625205,10679.12676315943,10633.713758296997,10563.593823093464,10475.666642067616,10394.48661058973,10307.337749004722],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#bcff3a\"},\"name\":\"12\",\"type\":\"scatter\",\"uid\":\"61d79e5b-1221-45cb-98b3-1242beb489c2\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47165370270082657,0.3578900265213915,0.2891560282862581,0.24083880524214488,0.207850463735504,0.183879329662469,0.16319167714340704,0.14789250815492916,0.1315299774179962,0.12372087214587789,0.11428466126416646,0.10883618535076436,0.10279474447387695,0.09766572146048448,0.09081568508209231,0.08593330607508279,0.08216375648793371,0.0791168136316962,0.07642694755200093,0.07384615302464889],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#e8ff0f\"},\"name\":\"13\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f19e77cb-2d25-4529-8f9d-292676f91911\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11074.304190284523,11270.074704391543,11337.646753844456,11393.767844361715,11382.432493098264,11342.026259991246,11307.597681129108,11335.171775993951,11250.6392542343,11213.12741872705,11110.772199549234,11064.251343517122,11042.858520545049,10922.450884499984,10850.738987811244,10785.376592676303,10674.168878679426,10522.16989205271,10443.42359965938,10348.15135432266],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#e8ff0f\"},\"name\":\"13\",\"type\":\"scatter\",\"uid\":\"b975dc71-da76-43e3-aba5-5e66b2b362c6\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.467342777429912,0.3416024423087205,0.27910321174567143,0.23050913043389606,0.19851418434126283,0.1756663406326525,0.15711892203701325,0.13858010782473795,0.12834380644402385,0.1171226350779017,0.1100739293920589,0.10251441617453542,0.09467131931672483,0.09072574589902667,0.08637417761144375,0.08205309967814466,0.0790759363245614,0.07772849740381059,0.07510736536848106,0.07265137671612938],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#ffd500\"},\"name\":\"14\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f406c043-0f1b-4be4-bd02-d94f4424682c\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11087.52557542617,11201.22705956107,11264.115790406604,11292.824638098962,11317.15699027003,11281.498582331276,11322.207028926732,11339.771680388227,11327.178998980202,11167.493221384164,11090.703318109807,10991.061715905907,10921.092013305804,10921.414809706115,10849.20591350587,10756.107814500603,10644.630217581205,10587.886446170434,10437.516867167407,10342.489678405149],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#ffd500\"},\"name\":\"14\",\"type\":\"scatter\",\"uid\":\"f4f96d29-4888-4662-ae72-f33b71ba24e7\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46565805426601725,0.3549669388200838,0.28907960083605916,0.2411840320437317,0.20445483555165378,0.18036279511146558,0.15735297031280943,0.13967623921493863,0.12582808284318311,0.1196681768510045,0.11138794680880144,0.1055940864813782,0.09923453037303112,0.09188690252759364,0.08696933388246794,0.08406815852725828,0.08086653912207462,0.07694310150792912,0.07586562190636095,0.07336532449072067],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#ffa400\"},\"name\":\"15\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"9eabf1b1-af2c-4e81-8768-d446a3a28868\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11068.046309185873,11150.1657775218,11259.927945300613,11258.671949226651,11266.893687156791,11275.907138982933,11188.304547244112,11219.76955522162,11200.243476725236,11135.251661568785,11027.9553934054,10929.698720441855,10834.157175493458,10882.486108740275,10770.225563673817,10675.837041470657,10617.65992960546,10487.333285002429,10387.978004645709,10300.551391623516],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#ffa400\"},\"name\":\"15\",\"type\":\"scatter\",\"uid\":\"da912a07-c85d-474a-a13e-4ab0fc16d9a4\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46932795796874316,0.3598819872397989,0.285055971973007,0.24047538038576205,0.20758977470283427,0.18247684789832205,0.16491868887500305,0.1456611303338732,0.130538472346563,0.12057559589816033,0.11339699738857592,0.10727304278755351,0.10171231167304949,0.09280065223916519,0.08879405804273395,0.0853581238153425,0.08131280053377832,0.07954659088876886,0.07699622231440464,0.07445860956230062],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#ff7200\"},\"name\":\"16\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"37e54be9-67a3-4172-8dba-f727dafc82dc\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10967.31969478168,11126.76319145041,11217.761301245822,11206.130309939237,11283.79566704848,11284.218727172118,11191.2011754941,11202.316834014986,11201.784297657408,11146.624926701426,11022.886564420533,10942.852665399472,10865.779600776847,10807.444186041452,10676.48415887533,10656.71918967577,10574.820743062714,10453.646767934868,10351.641526033645,10281.918724422572],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#ff7200\"},\"name\":\"16\",\"type\":\"scatter\",\"uid\":\"dcdc508f-a507-40b6-a41c-db2e6221e864\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4839489656161168,0.3618062130877226,0.2909150276359095,0.24583547261525907,0.20725074455177855,0.18050061388388047,0.16415609857638205,0.14437984693241662,0.12930093466256506,0.11929659161564003,0.11340474191644224,0.10641542212233497,0.10029313585188744,0.09450661081431391,0.0912832933961531,0.08583573790565022,0.08193986649167614,0.07966061032772183,0.07725470102319104,0.07431405273739546],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#ff4000\"},\"name\":\"17\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"62c1e18d-12fe-41d5-995b-738f08aca3c4\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11042.347172723761,11122.973037201844,11214.47667584529,11336.714091199528,11337.333756405553,11307.076261329576,11262.52884472405,11207.518823856928,11171.681766351456,11058.331353775344,11044.390776027116,10976.332366462924,10821.88548465819,10742.965724501102,10725.757122150602,10644.126114579372,10614.930269328564,10486.42793356228,10417.742463709848,10319.21159595824],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#ff4000\"},\"name\":\"17\",\"type\":\"scatter\",\"uid\":\"faed412c-4b19-448e-a03f-7de25c260f1d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4724737375219353,0.3620393874707304,0.28908163202480797,0.23539114185725982,0.20183083007143388,0.17676165818853307,0.15800650664756377,0.14388846834550909,0.1311422863027877,0.12300144214610709,0.11277399124395601,0.10539713038752788,0.10147886711690292,0.09667081343562228,0.09030685715510021,0.08580146888936005,0.0812276347565362,0.07912148699194729,0.07595030678843956,0.07373499783026392],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#fa0e00\"},\"name\":\"18\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"bcb43d1c-3d1d-4d40-941f-9a1e93fdf502\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11061.104094222763,11239.559981419903,11281.83666787449,11287.129683362742,11328.91317231443,11369.434920562888,11306.699883253495,11287.274234267423,11280.819840447972,11215.609120286588,11108.666525976647,11024.667197878096,10941.486197960681,10940.861997982878,10919.379371409235,10824.561557880075,10688.400325930346,10602.127733344892,10514.758739296245,10409.719642099037],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#fa0e00\"},\"name\":\"18\",\"type\":\"scatter\",\"uid\":\"e3f64937-0115-445e-8f7d-18d8c47febd5\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4680443054089132,0.3472347580873458,0.2836200023918088,0.24021190278159577,0.204274700539618,0.17542992782803585,0.157115459554543,0.14083908157267244,0.12665973122712754,0.11702302794897913,0.11040994489760712,0.10363904300376084,0.0981613234509696,0.09078706955631384,0.08479711521083538,0.08159847452703323,0.07953048480286444,0.07630910821344586,0.07363747785845441,0.07179028233909275],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#bd0000\"},\"name\":\"19\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"aee287b6-f3f2-497c-9244-788e44a2c620\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#bd0000\"},\"name\":\"19\",\"type\":\"scatter\",\"uid\":\"0159b052-6513-4d6b-88a2-46643e4e3804\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#800000\"},\"name\":\"20\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"9bc9047f-ccfb-4dd9-a766-c45bc26b309d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#800000\"},\"name\":\"20\",\"type\":\"scatter\",\"uid\":\"fb3e0b28-ae56-4285-8e0d-6ae38db43367\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"}],                        {\"height\":450,\"legend\":{\"title\":{\"text\":\"Iterations\"},\"traceorder\":\"reversed\"},\"margin\":{\"b\":25,\"l\":10,\"pad\":0,\"r\":135,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,0.45],\"tickformat\":\"g\",\"title\":{\"text\":\"$\\\\text{Velocity}~[\\\\text{km}~\\\\text{s}^{-1}]$\"}},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.55,1.0],\"matches\":\"x\",\"tickformat\":\"g\",\"title\":{\"text\":\"$\\\\text{Velocity}~[\\\\text{km}~\\\\text{s}^{-1}]$\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{rad}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$W$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('aa6510b2-12ea-47ca-ab5d-b292bbbe1bcd');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"0fba2c7c-48a0-4793-8422-a7e0789afc90\" class=\"plotly-graph-div\" style=\"height:630px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"0fba2c7c-48a0-4793-8422-a7e0789afc90\")) {                    Plotly.newPlot(                        \"0fba2c7c-48a0-4793-8422-a7e0789afc90\",                        [{\"hovertemplate\":\"<b>%{y:.3f}</b> at X = %{x:,.0f}<extra>Inner Boundary Temperature</extra>\",\"hovertext\":\"text\",\"mode\":\"lines\",\"name\":\"Inner<br>Boundary<br>Temperature\",\"type\":\"scatter\",\"uid\":\"ffb95594-a02e-47df-bce1-1f334efa268a\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x\",\"y\":[9933.951995919648,10703.211562422348,10673.712103958489,10635.953012231908,10638.406528771677,10650.201962584773,10645.954540809485,10642.04961793771,10636.106123877908,10654.31259429839,10628.189659670263,10644.054374080555,10653.542691388262,10647.276919600397,10638.875341023482,10655.125193761738,10655.56115672498,10636.535622734587,10641.692058870438,10650.463255529794],\"yaxis\":\"y\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"mode\":\"lines\",\"name\":\"Emitted<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"322d3629-ef4f-4144-8102-db93ed580d84\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[7.94217490576629e+42,1.0710516521093005e+43,1.0744260406037996e+43,1.0582996138891918e+43,1.0545940091430878e+43,1.0609681890774418e+43,1.0608322361748786e+43,1.0616467173322811e+43,1.0520605244141124e+43,1.0697420878067399e+43,1.0529798362530551e+43,1.0555093978401453e+43,1.0617727732344976e+43,1.062627715933488e+43,1.0528341253755922e+43,1.059103016026169e+43,1.0668824405561532e+43,1.057225256379625e+43,1.0557926285002873e+43,1.0607832431314582e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"mode\":\"lines\",\"name\":\"Absorbed<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"e1572b91-8810-4775-a309-bbc8836a2344\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[2.6585269987163907e+42,3.576326047128917e+42,3.3912529573296815e+42,3.351960855778322e+42,3.3988597390168757e+42,3.3980646035039864e+42,3.382148957209404e+42,3.3498688262362067e+42,3.4108734276587443e+42,3.334917848389675e+42,3.363215048559226e+42,3.419737826808236e+42,3.405731111443267e+42,3.3691331788887714e+42,3.41721250026907e+42,3.4445235238788086e+42,3.371808227073318e+42,3.3654653501429696e+42,3.40487735299688e+42,3.400790766998871e+42],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"mode\":\"lines\",\"name\":\"Requested<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"36ac7af7-90ed-435f-9bcd-cdd7edd87656\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.2f}%</b> at X = %{x:,.0f}\",\"mode\":\"lines\",\"name\":\"Residual<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"62b31e47-2b8c-4444-8a67-e2585d0f42d5\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x3\",\"y\":[-25.022636104275275,1.1116355710226051,1.4301915800245142,-0.09220874289084471,-0.44203291422789376,0.15971561705652318,0.1468811096714525,0.22377144619682712,-0.6812041849471281,0.9880073704063604,-0.59441740538123,-0.3556164952247293,0.2356716364643925,0.31638170721045433,-0.608173105315723,-0.016364310989694035,0.7180450300340984,-0.19363246486202446,-0.3288783680443794,0.1422559669511361],\"yaxis\":\"y3\"}],                        {\"height\":630,\"hoverlabel\":{\"align\":\"right\"},\"margin\":{\"b\":25,\"pad\":0,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x3\",\"range\":[0,21],\"showticklabels\":false},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x\",\"range\":[0,21],\"showticklabels\":false},\"xaxis3\":{\"anchor\":\"y3\",\"domain\":[0.0,1.0],\"dtick\":2,\"title\":{\"text\":\"$\\\\mbox{Iteration Number}$\"}},\"yaxis\":{\"anchor\":\"x\",\"automargin\":true,\"domain\":[0.79,1.0],\"exponentformat\":\"e\",\"nticks\":4,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{inner}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"automargin\":true,\"domain\":[0.29,0.71],\"exponentformat\":\"e\",\"nticks\":7,\"title\":{\"font\":{\"size\":13},\"text\":\"$\\\\text{Luminosity}~[\\\\text{erg s}^{-1}]$\"}},\"yaxis3\":{\"anchor\":\"x3\",\"automargin\":true,\"domain\":[0.0,0.21],\"nticks\":4,\"title\":{\"font\":{\"size\":12},\"text\":\"$~~\\\\text{Residual}\\\\\\\\\\\\text{Luminosity[%]}$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('0fba2c7c-48a0-4793-8422-a7e0789afc90');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from tardis import run_tardis\n",
    "from tardis.io.atom_data.util import download_atom_data\n",
    "\n",
    "# We download the atomic data needed to run the simulation\n",
    "download_atom_data('kurucz_cd23_chianti_H_He')\n",
    "\n",
    "# We run a simulation\n",
    "sim = run_tardis('tardis_example.yml', export_convergence_plots=True)"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "ae1623d6",
   "metadata": {},
   "source": [
    "## Displaying Convergence Plots\n",
    "You can also call the plots outside of `run_tardis` function. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "48768471",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2021-10-14T16:50:54.452071Z",
     "iopub.status.busy": "2021-10-14T16:50:54.448486Z",
     "iopub.status.idle": "2021-10-14T16:50:54.462491Z",
     "shell.execute_reply": "2021-10-14T16:50:54.461960Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"b3a1c53f-b031-4183-a84a-4b964d00c65b\" class=\"plotly-graph-div\" style=\"height:450px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"b3a1c53f-b031-4183-a84a-4b964d00c65b\")) {                    Plotly.newPlot(                        \"b3a1c53f-b031-4183-a84a-4b964d00c65b\",                        [{\"type\":\"scatter\",\"uid\":\"504f384e-5c8c-4ed3-90b7-c5151d60a66b\",\"xaxis\":\"x\",\"yaxis\":\"y\"},{\"type\":\"scatter\",\"uid\":\"068368d4-1fde-4244-bfc0-99eb1284ad5f\",\"xaxis\":\"x2\",\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#000080\"},\"name\":\"1\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"ba8521d2-54a3-4005-88c3-728c3acb0a60\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[9926.501965464813,9911.63537753482,9896.813253389762,9882.035393850509,9867.301600925806,9852.611677803428,9837.96542884143,9823.362659559447,9808.803176630105,9794.286787870464,9779.813302233586,9765.382529800137,9750.99428177009,9736.64837045449,9722.344609267282,9708.082812717237,9693.862796399926,9679.684376989773,9665.547372232175,9651.451600935694],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#000080\"},\"name\":\"1\",\"type\":\"scatter\",\"uid\":\"66b148fd-d43c-4f58-b2fa-950ae23e8311\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.40039163797855976,0.33245223097543924,0.2896679818236787,0.2577141002351936,0.23224568138195772,0.211204659222757,0.19341188222536587,0.17811401706296348,0.16479446041469908,0.15308090298851573,0.14269498356756605,0.13342261532969785,0.12509541040763922,0.11757848682757521,0.11076215248105115,0.10455605179542055,0.09888493580965113,0.09368553636653854,0.08890421153628925,0.08449514228457095],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#0000bd\"},\"name\":\"2\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"4a030947-7736-4016-b67e-5406bf87fe0f\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10140.644658439542,10163.140953757294,10199.392781222336,10228.793058184721,10271.14775928106,10224.009713529731,10228.732523936606,10216.98049975123,10217.783033963955,10193.706231603874,10148.77879424612,10080.136790247385,10031.646882137076,10030.254549667037,9988.12702379364,9874.634222100456,9844.474903130327,9776.381862231508,9680.562581778317,9611.593058427065],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#0000bd\"},\"name\":\"2\",\"type\":\"scatter\",\"uid\":\"4e164e36-6f2b-46b7-b07a-6793f37657bb\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5074939829206923,0.39593831162891974,0.32150485888655256,0.26573787630888046,0.2236515966575156,0.19686688849248643,0.1746427953806121,0.15625093331810624,0.13946942342362406,0.12759533918829524,0.11697794966442067,0.10915672831486313,0.10296463647641346,0.09515332126864076,0.08981745405810744,0.08689548233577285,0.08198790793189142,0.07881149990806682,0.07637264409196345,0.07345198061495406],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#0000fa\"},\"name\":\"3\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"c50ce403-4912-4a3a-9fef-788a9f3e4dab\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10821.384716452621,10824.07375074843,10898.794282582267,10931.581728038504,10962.883353030435,10956.472449386303,10935.661811838689,10896.394485335457,10868.778286813804,10846.86064742898,10799.242899977486,10741.078256171444,10679.03654492254,10616.6413627693,10548.485755133186,10483.027318852863,10402.58849317583,10353.528838881304,10280.790364670062,10205.89807450607],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#0000fa\"},\"name\":\"3\",\"type\":\"scatter\",\"uid\":\"baedddde-a639-492d-833a-5150f927b366\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5246621760292516,0.41191697242104813,0.33082428419284166,0.2739415803649503,0.23102276356532733,0.20265771066458735,0.18068103823778522,0.16215467464075065,0.14618948104529478,0.13362668956992607,0.12450448547982709,0.11605105087549335,0.10925211388307239,0.10302987363746915,0.09831778993852412,0.0932577131276202,0.08908435787384879,0.08446805448195224,0.08117712884118686,0.07815148665239906],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#0022ff\"},\"name\":\"4\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"d4dc6e33-8f86-4dbb-964b-f9a2288ba8aa\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11001.634918288773,11064.199689011095,11146.787545057517,11182.280653331733,11189.736123692379,11179.454369423816,11213.79207405269,11157.651049771417,11091.366692176987,11032.681911673413,10951.71311170724,10882.347593647743,10815.56574149097,10758.062388449993,10666.645789560242,10589.476597771141,10519.279070600585,10489.380846260961,10394.331364500693,10280.44535660762],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#0022ff\"},\"name\":\"4\",\"type\":\"scatter\",\"uid\":\"d3185c2c-2d08-4ed8-91fd-a795f4e679c9\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.48255611027402595,0.37531673900188744,0.3008854405436438,0.24970650566435726,0.21504788747697892,0.1889210232599808,0.16485989155704653,0.14922567218546676,0.1373433490366653,0.1270628239280638,0.11816510452204829,0.11046612213518453,0.10408751562676459,0.09837704095780829,0.09380107799147919,0.08948233963910264,0.08532986022143939,0.08049857949608492,0.07819235373949822,0.07599589756382483],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#0057ff\"},\"name\":\"5\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"6c607107-fbba-438b-aa82-fffd10d5cc58\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.69813331972,11131.435799441577,11213.984633035107,11254.938537458936,11264.10756107921,11231.114026250594,11180.234767099426,11161.43757582825,11095.861090734456,11098.458607564848,11036.771405771051,10960.49690639981,10968.575819463373,10890.828989905996,10799.341137335274,10659.853383147958,10549.231623432072,10506.788250185065,10398.595227817385,10289.349894730598],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#0057ff\"},\"name\":\"5\",\"type\":\"scatter\",\"uid\":\"bcec50e9-587c-422f-8e91-5bf985548eda\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46875384769180994,0.3582440793604906,0.2859963458991618,0.23841076673448683,0.20840515079453156,0.18245979900971618,0.1638530282293532,0.14657197302070762,0.13503875104453528,0.12203984302262225,0.11334205862439253,0.10619057923554849,0.09765445785021042,0.09265039020379297,0.08856994824064786,0.0861030166939687,0.08350964472774987,0.07926097434257318,0.07675258324197402,0.07475268831395629],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#008dff\"},\"name\":\"6\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"e4cf7f48-75e7-4659-88cf-4ad307f0b4f5\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11004.024489659887,11119.370907976154,11195.435272777357,11259.07218492983,11285.20780804646,11285.17736284529,11257.669785381573,11225.435571936492,11186.445768225169,11099.126705981142,11029.754124780751,10939.09235294023,10877.977505280129,10799.952863140219,10803.94962659834,10716.294187213076,10608.39027776731,10536.800302652608,10451.345002096903,10351.499433918842],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#008dff\"},\"name\":\"6\",\"type\":\"scatter\",\"uid\":\"1afe8085-1c5e-4fd6-8400-825787989256\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47879511389335816,0.36722911837191247,0.2926208974449371,0.24239288815881765,0.20444578448470932,0.17802906434287452,0.15880728036632202,0.14352699270970695,0.13113431023478964,0.12123492206018885,0.11293848121019129,0.107206115377895,0.09996151019829129,0.09452711171505655,0.08773741567449585,0.0838574125841496,0.08091696481124855,0.07741620755854674,0.07503066951006154,0.0727305286162828],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#00c3ff\"},\"name\":\"7\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"3933263b-fb87-4877-83f4-13e1eb33d34d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11049.228732355552,11156.739354515785,11233.159171838806,11257.86819871853,11259.221213382081,11218.728487793938,11177.383540027478,11170.932602943105,11091.339644892223,11058.83258870618,11086.886472116763,10967.000400044035,10888.705512509965,10859.351173962054,10794.116212447141,10665.940454226306,10614.036765336794,10560.167635600494,10433.600109025549,10347.135454231406],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#00c3ff\"},\"name\":\"7\",\"type\":\"scatter\",\"uid\":\"87526170-889b-4ef0-b6ea-f618c03fcf72\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4697400940159998,0.3588700697047573,0.29077776563828756,0.2443651184699209,0.20776673425141715,0.1852074960564398,0.16487114788798946,0.14711076442391682,0.13525030370898636,0.12403257789506693,0.11208234573021662,0.10708808842987298,0.1008199099410747,0.09351009430956675,0.08797758265708822,0.08557481001143187,0.08167863229931253,0.07764065281949213,0.07578960072572662,0.07324774090303579],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#0ff8e8\"},\"name\":\"8\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"70447eaf-ba12-40e1-8852-cae02c753a46\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11037.08503719401,11149.996498693195,11245.895992066266,11293.021085350518,11348.844546340542,11303.81450750131,11275.886160361555,11193.561854480458,11139.762040353016,11142.50167244028,11052.1571050735,10947.278343765189,10930.67339710046,10870.232618754231,10717.538511627446,10653.978725318402,10563.0762100547,10483.387471111888,10423.15401494719,10305.26962980183],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#0ff8e8\"},\"name\":\"8\",\"type\":\"scatter\",\"uid\":\"9dd9c60f-dc05-4561-9a29-5061120c6962\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46951709287046905,0.3558132377939077,0.28344389342857873,0.23679038121368734,0.2006318674457632,0.17752655689561797,0.15896810063770853,0.14566983788022744,0.13249513450931652,0.11945436911075241,0.11202516442423788,0.10653028310041686,0.09880763358506521,0.09250430944965742,0.0904904576740684,0.08597716733696596,0.08263854439908624,0.07942790299289659,0.07616188750490346,0.07438003691528026],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#3affbc\"},\"name\":\"9\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"d73ca3e5-1ecc-4497-b43c-77e55c0f0906\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11052.295325497007,11212.705361919509,11368.864591182264,11398.78996374572,11425.824065083918,11374.755681704642,11321.373184735603,11274.453385553123,11206.414763213426,11152.830452841748,11103.737908148854,10987.81945397592,10971.696465389161,10850.543109804723,10728.169760230841,10715.360231738356,10614.329903571434,10533.835974010104,10505.237794759547,10368.71936512106],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#3affbc\"},\"name\":\"9\",\"type\":\"scatter\",\"uid\":\"7d9323bd-004e-41e4-9e75-d9148f7c38ff\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47175098459955545,0.3533364312643379,0.27692864002604506,0.23227462876251695,0.1992339273085163,0.1752154543235442,0.15695860796865863,0.1425401542709221,0.12987043769720186,0.1194981244007122,0.11065799714369325,0.10503597469582807,0.09725717606234426,0.09312192856965566,0.08970996968103623,0.0840348909677989,0.08128474934784594,0.07834393294338478,0.0738203172283877,0.07253718289337063],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#66ff91\"},\"name\":\"10\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"bfc49949-0d05-4ed8-a5f8-9a5b07643a36\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11054.591787334148,11225.528282829357,11397.756567710436,11384.015365915013,11451.389274254923,11459.610588977725,11376.050029186565,11274.095516148473,11272.499217755421,11178.085961626613,11140.791754287642,11068.611912757306,11035.291654969596,10948.379622684975,10846.30843479845,10760.164548553728,10717.142639062211,10660.04707328942,10504.059452325992,10393.011181236432],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#66ff91\"},\"name\":\"10\",\"type\":\"scatter\",\"uid\":\"3fdc3a52-e5fd-4de8-8c6f-60857fa88057\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46869175429362847,0.3489553241372833,0.272245622698486,0.23088331103266788,0.19396911644591475,0.16966303737984223,0.15365541714258069,0.14066857846930758,0.12625486648965414,0.11769844507310218,0.10873442822036551,0.10217357366795128,0.09428760780374013,0.08974201060071937,0.08619004289280512,0.08223115714542878,0.07778821666696925,0.07403971132288675,0.07307298001360511,0.07131405537195114],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#91ff66\"},\"name\":\"11\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"915feae1-c564-4fc8-bab5-3ef0392a3b31\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.824129738192,11205.221198116975,11257.276210948365,11249.982124832772,11346.90454878048,11369.200845314623,11327.975637400814,11265.70277970273,11242.69566867425,11125.713354976318,11085.643189312845,11003.766807453341,10952.925463047199,10818.865962225485,10751.827669918477,10622.890289468805,10581.153922616171,10457.765325669847,10406.863293593042,10293.690965995087],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#91ff66\"},\"name\":\"11\",\"type\":\"scatter\",\"uid\":\"92caea74-e76a-45ac-823b-dc1ce46965f3\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4745474662644775,0.35492209696573995,0.2908775211495747,0.24470866481882064,0.20504347418985933,0.17741364784201571,0.158531848563811,0.14501821946430396,0.13008713859723542,0.12233533943053944,0.11238724105660731,0.10569730424606064,0.09826037906138733,0.09469637422940755,0.0899277992037678,0.0877518224215559,0.08291661849234434,0.08063515139722367,0.07697286067066779,0.07517475455159717],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#bcff3a\"},\"name\":\"12\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"4228edf1-0001-48a6-9da5-b12eb5f63e91\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11033.00930341031,11148.879430055598,11221.615762493011,11261.57342812569,11263.081991396044,11194.36101620315,11176.653686173815,11119.362957181675,11160.897203210388,11060.87637020031,11002.1449565465,10869.256977805022,10791.657316178955,10690.963307625205,10679.12676315943,10633.713758296997,10563.593823093464,10475.666642067616,10394.48661058973,10307.337749004722],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#bcff3a\"},\"name\":\"12\",\"type\":\"scatter\",\"uid\":\"61d79e5b-1221-45cb-98b3-1242beb489c2\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47165370270082657,0.3578900265213915,0.2891560282862581,0.24083880524214488,0.207850463735504,0.183879329662469,0.16319167714340704,0.14789250815492916,0.1315299774179962,0.12372087214587789,0.11428466126416646,0.10883618535076436,0.10279474447387695,0.09766572146048448,0.09081568508209231,0.08593330607508279,0.08216375648793371,0.0791168136316962,0.07642694755200093,0.07384615302464889],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#e8ff0f\"},\"name\":\"13\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f19e77cb-2d25-4529-8f9d-292676f91911\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11074.304190284523,11270.074704391543,11337.646753844456,11393.767844361715,11382.432493098264,11342.026259991246,11307.597681129108,11335.171775993951,11250.6392542343,11213.12741872705,11110.772199549234,11064.251343517122,11042.858520545049,10922.450884499984,10850.738987811244,10785.376592676303,10674.168878679426,10522.16989205271,10443.42359965938,10348.15135432266],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#e8ff0f\"},\"name\":\"13\",\"type\":\"scatter\",\"uid\":\"b975dc71-da76-43e3-aba5-5e66b2b362c6\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.467342777429912,0.3416024423087205,0.27910321174567143,0.23050913043389606,0.19851418434126283,0.1756663406326525,0.15711892203701325,0.13858010782473795,0.12834380644402385,0.1171226350779017,0.1100739293920589,0.10251441617453542,0.09467131931672483,0.09072574589902667,0.08637417761144375,0.08205309967814466,0.0790759363245614,0.07772849740381059,0.07510736536848106,0.07265137671612938],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#ffd500\"},\"name\":\"14\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f406c043-0f1b-4be4-bd02-d94f4424682c\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11087.52557542617,11201.22705956107,11264.115790406604,11292.824638098962,11317.15699027003,11281.498582331276,11322.207028926732,11339.771680388227,11327.178998980202,11167.493221384164,11090.703318109807,10991.061715905907,10921.092013305804,10921.414809706115,10849.20591350587,10756.107814500603,10644.630217581205,10587.886446170434,10437.516867167407,10342.489678405149],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#ffd500\"},\"name\":\"14\",\"type\":\"scatter\",\"uid\":\"f4f96d29-4888-4662-ae72-f33b71ba24e7\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46565805426601725,0.3549669388200838,0.28907960083605916,0.2411840320437317,0.20445483555165378,0.18036279511146558,0.15735297031280943,0.13967623921493863,0.12582808284318311,0.1196681768510045,0.11138794680880144,0.1055940864813782,0.09923453037303112,0.09188690252759364,0.08696933388246794,0.08406815852725828,0.08086653912207462,0.07694310150792912,0.07586562190636095,0.07336532449072067],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#ffa400\"},\"name\":\"15\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"9eabf1b1-af2c-4e81-8768-d446a3a28868\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11068.046309185873,11150.1657775218,11259.927945300613,11258.671949226651,11266.893687156791,11275.907138982933,11188.304547244112,11219.76955522162,11200.243476725236,11135.251661568785,11027.9553934054,10929.698720441855,10834.157175493458,10882.486108740275,10770.225563673817,10675.837041470657,10617.65992960546,10487.333285002429,10387.978004645709,10300.551391623516],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#ffa400\"},\"name\":\"15\",\"type\":\"scatter\",\"uid\":\"da912a07-c85d-474a-a13e-4ab0fc16d9a4\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46932795796874316,0.3598819872397989,0.285055971973007,0.24047538038576205,0.20758977470283427,0.18247684789832205,0.16491868887500305,0.1456611303338732,0.130538472346563,0.12057559589816033,0.11339699738857592,0.10727304278755351,0.10171231167304949,0.09280065223916519,0.08879405804273395,0.0853581238153425,0.08131280053377832,0.07954659088876886,0.07699622231440464,0.07445860956230062],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#ff7200\"},\"name\":\"16\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"37e54be9-67a3-4172-8dba-f727dafc82dc\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10967.31969478168,11126.76319145041,11217.761301245822,11206.130309939237,11283.79566704848,11284.218727172118,11191.2011754941,11202.316834014986,11201.784297657408,11146.624926701426,11022.886564420533,10942.852665399472,10865.779600776847,10807.444186041452,10676.48415887533,10656.71918967577,10574.820743062714,10453.646767934868,10351.641526033645,10281.918724422572],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#ff7200\"},\"name\":\"16\",\"type\":\"scatter\",\"uid\":\"dcdc508f-a507-40b6-a41c-db2e6221e864\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4839489656161168,0.3618062130877226,0.2909150276359095,0.24583547261525907,0.20725074455177855,0.18050061388388047,0.16415609857638205,0.14437984693241662,0.12930093466256506,0.11929659161564003,0.11340474191644224,0.10641542212233497,0.10029313585188744,0.09450661081431391,0.0912832933961531,0.08583573790565022,0.08193986649167614,0.07966061032772183,0.07725470102319104,0.07431405273739546],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#ff4000\"},\"name\":\"17\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"62c1e18d-12fe-41d5-995b-738f08aca3c4\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11042.347172723761,11122.973037201844,11214.47667584529,11336.714091199528,11337.333756405553,11307.076261329576,11262.52884472405,11207.518823856928,11171.681766351456,11058.331353775344,11044.390776027116,10976.332366462924,10821.88548465819,10742.965724501102,10725.757122150602,10644.126114579372,10614.930269328564,10486.42793356228,10417.742463709848,10319.21159595824],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#ff4000\"},\"name\":\"17\",\"type\":\"scatter\",\"uid\":\"faed412c-4b19-448e-a03f-7de25c260f1d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4724737375219353,0.3620393874707304,0.28908163202480797,0.23539114185725982,0.20183083007143388,0.17676165818853307,0.15800650664756377,0.14388846834550909,0.1311422863027877,0.12300144214610709,0.11277399124395601,0.10539713038752788,0.10147886711690292,0.09667081343562228,0.09030685715510021,0.08580146888936005,0.0812276347565362,0.07912148699194729,0.07595030678843956,0.07373499783026392],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#fa0e00\"},\"name\":\"18\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"bcb43d1c-3d1d-4d40-941f-9a1e93fdf502\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11061.104094222763,11239.559981419903,11281.83666787449,11287.129683362742,11328.91317231443,11369.434920562888,11306.699883253495,11287.274234267423,11280.819840447972,11215.609120286588,11108.666525976647,11024.667197878096,10941.486197960681,10940.861997982878,10919.379371409235,10824.561557880075,10688.400325930346,10602.127733344892,10514.758739296245,10409.719642099037],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#fa0e00\"},\"name\":\"18\",\"type\":\"scatter\",\"uid\":\"e3f64937-0115-445e-8f7d-18d8c47febd5\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4680443054089132,0.3472347580873458,0.2836200023918088,0.24021190278159577,0.204274700539618,0.17542992782803585,0.157115459554543,0.14083908157267244,0.12665973122712754,0.11702302794897913,0.11040994489760712,0.10363904300376084,0.0981613234509696,0.09078706955631384,0.08479711521083538,0.08159847452703323,0.07953048480286444,0.07630910821344586,0.07363747785845441,0.07179028233909275],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#bd0000\"},\"name\":\"19\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"aee287b6-f3f2-497c-9244-788e44a2c620\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#bd0000\"},\"name\":\"19\",\"type\":\"scatter\",\"uid\":\"0159b052-6513-4d6b-88a2-46643e4e3804\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#800000\"},\"name\":\"20\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"9bc9047f-ccfb-4dd9-a766-c45bc26b309d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#800000\"},\"name\":\"20\",\"type\":\"scatter\",\"uid\":\"fb3e0b28-ae56-4285-8e0d-6ae38db43367\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"}],                        {\"height\":450,\"legend\":{\"title\":{\"text\":\"Iterations\"},\"traceorder\":\"reversed\"},\"margin\":{\"b\":25,\"l\":10,\"pad\":0,\"r\":135,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,0.45],\"tickformat\":\"g\",\"title\":{\"text\":\"$\\\\text{Velocity}~[\\\\text{km}~\\\\text{s}^{-1}]$\"}},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.55,1.0],\"matches\":\"x\",\"tickformat\":\"g\",\"title\":{\"text\":\"$\\\\text{Velocity}~[\\\\text{km}~\\\\text{s}^{-1}]$\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{rad}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$W$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('b3a1c53f-b031-4183-a84a-4b964d00c65b');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "sim.convergence_plots.plasma_plot.show(renderer=\"notebook_connected\")"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "9db6b395",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2021-10-14T16:50:54.468844Z",
     "iopub.status.busy": "2021-10-14T16:50:54.468207Z",
     "iopub.status.idle": "2021-10-14T16:50:54.473322Z",
     "shell.execute_reply": "2021-10-14T16:50:54.473824Z"
    }
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"75127990-5ece-4109-afb3-20143523ebed\" class=\"plotly-graph-div\" style=\"height:630px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"75127990-5ece-4109-afb3-20143523ebed\")) {                    Plotly.newPlot(                        \"75127990-5ece-4109-afb3-20143523ebed\",                        [{\"hovertemplate\":\"<b>%{y:.3f}</b> at X = %{x:,.0f}<extra>Inner Boundary Temperature</extra>\",\"hovertext\":\"text\",\"mode\":\"lines\",\"name\":\"Inner<br>Boundary<br>Temperature\",\"type\":\"scatter\",\"uid\":\"ffb95594-a02e-47df-bce1-1f334efa268a\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x\",\"y\":[9933.951995919648,10703.211562422348,10673.712103958489,10635.953012231908,10638.406528771677,10650.201962584773,10645.954540809485,10642.04961793771,10636.106123877908,10654.31259429839,10628.189659670263,10644.054374080555,10653.542691388262,10647.276919600397,10638.875341023482,10655.125193761738,10655.56115672498,10636.535622734587,10641.692058870438,10650.463255529794],\"yaxis\":\"y\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"mode\":\"lines\",\"name\":\"Emitted<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"322d3629-ef4f-4144-8102-db93ed580d84\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[7.94217490576629e+42,1.0710516521093005e+43,1.0744260406037996e+43,1.0582996138891918e+43,1.0545940091430878e+43,1.0609681890774418e+43,1.0608322361748786e+43,1.0616467173322811e+43,1.0520605244141124e+43,1.0697420878067399e+43,1.0529798362530551e+43,1.0555093978401453e+43,1.0617727732344976e+43,1.062627715933488e+43,1.0528341253755922e+43,1.059103016026169e+43,1.0668824405561532e+43,1.057225256379625e+43,1.0557926285002873e+43,1.0607832431314582e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"mode\":\"lines\",\"name\":\"Absorbed<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"e1572b91-8810-4775-a309-bbc8836a2344\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[2.6585269987163907e+42,3.576326047128917e+42,3.3912529573296815e+42,3.351960855778322e+42,3.3988597390168757e+42,3.3980646035039864e+42,3.382148957209404e+42,3.3498688262362067e+42,3.4108734276587443e+42,3.334917848389675e+42,3.363215048559226e+42,3.419737826808236e+42,3.405731111443267e+42,3.3691331788887714e+42,3.41721250026907e+42,3.4445235238788086e+42,3.371808227073318e+42,3.3654653501429696e+42,3.40487735299688e+42,3.400790766998871e+42],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"mode\":\"lines\",\"name\":\"Requested<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"36ac7af7-90ed-435f-9bcd-cdd7edd87656\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.2f}%</b> at X = %{x:,.0f}\",\"mode\":\"lines\",\"name\":\"Residual<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"62b31e47-2b8c-4444-8a67-e2585d0f42d5\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x3\",\"y\":[-25.022636104275275,1.1116355710226051,1.4301915800245142,-0.09220874289084471,-0.44203291422789376,0.15971561705652318,0.1468811096714525,0.22377144619682712,-0.6812041849471281,0.9880073704063604,-0.59441740538123,-0.3556164952247293,0.2356716364643925,0.31638170721045433,-0.608173105315723,-0.016364310989694035,0.7180450300340984,-0.19363246486202446,-0.3288783680443794,0.1422559669511361],\"yaxis\":\"y3\"}],                        {\"height\":630,\"hoverlabel\":{\"align\":\"right\"},\"margin\":{\"b\":25,\"pad\":0,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x3\",\"range\":[0,21],\"showticklabels\":false},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x\",\"range\":[0,21],\"showticklabels\":false},\"xaxis3\":{\"anchor\":\"y3\",\"domain\":[0.0,1.0],\"dtick\":2,\"title\":{\"text\":\"$\\\\mbox{Iteration Number}$\"}},\"yaxis\":{\"anchor\":\"x\",\"automargin\":true,\"domain\":[0.79,1.0],\"exponentformat\":\"e\",\"nticks\":4,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{inner}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"automargin\":true,\"domain\":[0.29,0.71],\"exponentformat\":\"e\",\"nticks\":7,\"title\":{\"font\":{\"size\":13},\"text\":\"$\\\\text{Luminosity}~[\\\\text{erg s}^{-1}]$\"}},\"yaxis3\":{\"anchor\":\"x3\",\"automargin\":true,\"domain\":[0.0,0.21],\"nticks\":4,\"title\":{\"font\":{\"size\":12},\"text\":\"$~~\\\\text{Residual}\\\\\\\\\\\\text{Luminosity[%]}$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('75127990-5ece-4109-afb3-20143523ebed');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "sim.convergence_plots.t_inner_luminosities_plot.show(renderer=\"notebook_connected\")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "b1bf44fa",
   "metadata": {},
   "source": [
    "## Changing Line Colors\n",
    "The default line-colors of the plasma plots can be changed by passing the name of the cmap in the `plasma_cmap` option. \n",
    "\n",
    "```py\n",
    "sim = run_tardis(\"tardis_example.yml\",plasma_cmap= \"viridis\")\n",
    "```\n",
    "\n",
    "Alongwith the cmap name, one can also provide a list of colors in rgb, hex or css-names format in the `t_inner_luminosities_colors` option to change the default colors of the luminosity and inner boundary temperature plots. \n",
    "```py\n",
    "# hex colors example list\n",
    "colors = [\n",
    "    '#8c564b',  # chestnut brown\n",
    "    '#e377c2',  # raspberry yogurt pink\n",
    "    '#7f7f7f',  # middle gray\n",
    "    '#bcbd22',  # curry yellow-green\n",
    "    '#17becf'   # blue-teal\n",
    "]\n",
    "\n",
    "# rgb colors example list\n",
    "colors = ['rgb(31, 119, 180)',\n",
    "          'rgb(255, 127, 14)',\n",
    "          'rgb(44, 160, 44)', \n",
    "          'rgb(214, 39, 40)',\n",
    "          'rgb(148, 103, 189)',]\n",
    "          \n",
    "# css colors\n",
    "colors = [\"indigo\",\"lightseagreen\", \"midnightblue\",  \"pink\", \"teal\"]\n",
    "```\n",
    "For more css-names please see [this](https://www.w3schools.com/colors/colors_names.asp). "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "9109967e",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2021-10-14T16:50:54.477212Z",
     "iopub.status.busy": "2021-10-14T16:50:54.476592Z",
     "iopub.status.idle": "2021-10-14T16:51:31.654081Z",
     "shell.execute_reply": "2021-10-14T16:51:31.653517Z"
    },
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "2d71663b0a974953a09e4d7545c735de",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "TqdmHBox(children=(HTML(value='Iterations:', layout=Layout(width='6%')), FloatProgress(value=0.0, layout=Layou…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d45c31175c6d4d55a4a1ecdad2fe64ba",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "TqdmHBox(children=(HTML(value='Packets:   ', layout=Layout(width='6%')), FloatProgress(value=0.0, layout=Layou…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d401a25f470d4136a349638cd50685c8",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "VBox(children=(FigureWidget({\n",
       "    'data': [{'type': 'scatter', 'uid': '1599e719-fbc4-4e17-802b-21d28bb59e3e', …"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"2bbaa61e-6fdf-49e2-a33e-0ef4f1f2270c\" class=\"plotly-graph-div\" style=\"height:450px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"2bbaa61e-6fdf-49e2-a33e-0ef4f1f2270c\")) {                    Plotly.newPlot(                        \"2bbaa61e-6fdf-49e2-a33e-0ef4f1f2270c\",                        [{\"type\":\"scatter\",\"uid\":\"1599e719-fbc4-4e17-802b-21d28bb59e3e\",\"xaxis\":\"x\",\"yaxis\":\"y\"},{\"type\":\"scatter\",\"uid\":\"0957fb1d-729c-48c6-9910-f74c23040b38\",\"xaxis\":\"x2\",\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#440154\"},\"name\":\"1\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"b5869d14-d975-4526-9664-e0ac0c08a868\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[9926.501965464813,9911.63537753482,9896.813253389762,9882.035393850509,9867.301600925806,9852.611677803428,9837.96542884143,9823.362659559447,9808.803176630105,9794.286787870464,9779.813302233586,9765.382529800137,9750.99428177009,9736.64837045449,9722.344609267282,9708.082812717237,9693.862796399926,9679.684376989773,9665.547372232175,9651.451600935694],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#440154\"},\"name\":\"1\",\"type\":\"scatter\",\"uid\":\"f896ff72-c055-40e4-a8a1-e570622a3ec8\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.40039163797855976,0.33245223097543924,0.2896679818236787,0.2577141002351936,0.23224568138195772,0.211204659222757,0.19341188222536587,0.17811401706296348,0.16479446041469908,0.15308090298851573,0.14269498356756605,0.13342261532969785,0.12509541040763922,0.11757848682757521,0.11076215248105115,0.10455605179542055,0.09888493580965113,0.09368553636653854,0.08890421153628925,0.08449514228457095],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#481467\"},\"name\":\"2\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"c79119cc-6219-48d5-8550-a7c600395b43\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10140.644658439542,10163.140953757294,10199.392781222336,10228.793058184721,10271.14775928106,10224.009713529731,10228.732523936606,10216.98049975123,10217.783033963955,10193.706231603874,10148.77879424612,10080.136790247385,10031.646882137076,10030.254549667037,9988.12702379364,9874.634222100456,9844.474903130327,9776.381862231508,9680.562581778317,9611.593058427065],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#481467\"},\"name\":\"2\",\"type\":\"scatter\",\"uid\":\"39647c08-91d4-437a-9647-e139b41ee37c\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5074939829206923,0.39593831162891974,0.32150485888655256,0.26573787630888046,0.2236515966575156,0.19686688849248643,0.1746427953806121,0.15625093331810624,0.13946942342362406,0.12759533918829524,0.11697794966442067,0.10915672831486313,0.10296463647641346,0.09515332126864076,0.08981745405810744,0.08689548233577285,0.08198790793189142,0.07881149990806682,0.07637264409196345,0.07345198061495406],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#482576\"},\"name\":\"3\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"4ca492b9-a335-40fd-bde5-5e8649525ffd\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10821.384716452621,10824.07375074843,10898.794282582267,10931.581728038504,10962.883353030435,10956.472449386303,10935.661811838689,10896.394485335457,10868.778286813804,10846.86064742898,10799.242899977486,10741.078256171444,10679.03654492254,10616.6413627693,10548.485755133186,10483.027318852863,10402.58849317583,10353.528838881304,10280.790364670062,10205.89807450607],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#482576\"},\"name\":\"3\",\"type\":\"scatter\",\"uid\":\"c1384871-f728-4654-a300-4d6b2ec3745e\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5246621760292516,0.41191697242104813,0.33082428419284166,0.2739415803649503,0.23102276356532733,0.20265771066458735,0.18068103823778522,0.16215467464075065,0.14618948104529478,0.13362668956992607,0.12450448547982709,0.11605105087549335,0.10925211388307239,0.10302987363746915,0.09831778993852412,0.0932577131276202,0.08908435787384879,0.08446805448195224,0.08117712884118686,0.07815148665239906],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#453781\"},\"name\":\"4\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"a5ea9b80-5a18-4598-b419-cc64dafb64cf\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11001.634918288773,11064.199689011095,11146.787545057517,11182.280653331733,11189.736123692379,11179.454369423816,11213.79207405269,11157.651049771417,11091.366692176987,11032.681911673413,10951.71311170724,10882.347593647743,10815.56574149097,10758.062388449993,10666.645789560242,10589.476597771141,10519.279070600585,10489.380846260961,10394.331364500693,10280.44535660762],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#453781\"},\"name\":\"4\",\"type\":\"scatter\",\"uid\":\"0b35bf55-9042-405c-9f7f-7524c20e198d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.48255611027402595,0.37531673900188744,0.3008854405436438,0.24970650566435726,0.21504788747697892,0.1889210232599808,0.16485989155704653,0.14922567218546676,0.1373433490366653,0.1270628239280638,0.11816510452204829,0.11046612213518453,0.10408751562676459,0.09837704095780829,0.09380107799147919,0.08948233963910264,0.08532986022143939,0.08049857949608492,0.07819235373949822,0.07599589756382483],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#404688\"},\"name\":\"5\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"091bfede-a431-48fb-a040-40b559b0f0db\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.69813331972,11131.435799441577,11213.984633035107,11254.938537458936,11264.10756107921,11231.114026250594,11180.234767099426,11161.43757582825,11095.861090734456,11098.458607564848,11036.771405771051,10960.49690639981,10968.575819463373,10890.828989905996,10799.341137335274,10659.853383147958,10549.231623432072,10506.788250185065,10398.595227817385,10289.349894730598],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#404688\"},\"name\":\"5\",\"type\":\"scatter\",\"uid\":\"602d0603-6369-4b79-afdd-1e695a856b7d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46875384769180994,0.3582440793604906,0.2859963458991618,0.23841076673448683,0.20840515079453156,0.18245979900971618,0.1638530282293532,0.14657197302070762,0.13503875104453528,0.12203984302262225,0.11334205862439253,0.10619057923554849,0.09765445785021042,0.09265039020379297,0.08856994824064786,0.0861030166939687,0.08350964472774987,0.07926097434257318,0.07675258324197402,0.07475268831395629],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#39558c\"},\"name\":\"6\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"cde00ad3-cf44-4748-9882-97e5465114f0\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11004.024489659887,11119.370907976154,11195.435272777357,11259.07218492983,11285.20780804646,11285.17736284529,11257.669785381573,11225.435571936492,11186.445768225169,11099.126705981142,11029.754124780751,10939.09235294023,10877.977505280129,10799.952863140219,10803.94962659834,10716.294187213076,10608.39027776731,10536.800302652608,10451.345002096903,10351.499433918842],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#39558c\"},\"name\":\"6\",\"type\":\"scatter\",\"uid\":\"80f83280-e20f-4fd2-af69-ab5494bdb8ea\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47879511389335816,0.36722911837191247,0.2926208974449371,0.24239288815881765,0.20444578448470932,0.17802906434287452,0.15880728036632202,0.14352699270970695,0.13113431023478964,0.12123492206018885,0.11293848121019129,0.107206115377895,0.09996151019829129,0.09452711171505655,0.08773741567449585,0.0838574125841496,0.08091696481124855,0.07741620755854674,0.07503066951006154,0.0727305286162828],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#33638d\"},\"name\":\"7\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"3d6ed3d4-8135-4823-85c9-0cc8ef0e379f\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11049.228732355552,11156.739354515785,11233.159171838806,11257.86819871853,11259.221213382081,11218.728487793938,11177.383540027478,11170.932602943105,11091.339644892223,11058.83258870618,11086.886472116763,10967.000400044035,10888.705512509965,10859.351173962054,10794.116212447141,10665.940454226306,10614.036765336794,10560.167635600494,10433.600109025549,10347.135454231406],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#33638d\"},\"name\":\"7\",\"type\":\"scatter\",\"uid\":\"3995425f-84d3-4f30-8234-f8a8159181eb\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4697400940159998,0.3588700697047573,0.29077776563828756,0.2443651184699209,0.20776673425141715,0.1852074960564398,0.16487114788798946,0.14711076442391682,0.13525030370898636,0.12403257789506693,0.11208234573021662,0.10708808842987298,0.1008199099410747,0.09351009430956675,0.08797758265708822,0.08557481001143187,0.08167863229931253,0.07764065281949213,0.07578960072572662,0.07324774090303579],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#2d718e\"},\"name\":\"8\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"63179d75-f8b5-4083-b17d-9a7765b41c52\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11037.08503719401,11149.996498693195,11245.895992066266,11293.021085350518,11348.844546340542,11303.81450750131,11275.886160361555,11193.561854480458,11139.762040353016,11142.50167244028,11052.1571050735,10947.278343765189,10930.67339710046,10870.232618754231,10717.538511627446,10653.978725318402,10563.0762100547,10483.387471111888,10423.15401494719,10305.26962980183],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#2d718e\"},\"name\":\"8\",\"type\":\"scatter\",\"uid\":\"4eac5fab-7450-4dd1-aed4-a7ba418f70ad\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46951709287046905,0.3558132377939077,0.28344389342857873,0.23679038121368734,0.2006318674457632,0.17752655689561797,0.15896810063770853,0.14566983788022744,0.13249513450931652,0.11945436911075241,0.11202516442423788,0.10653028310041686,0.09880763358506521,0.09250430944965742,0.0904904576740684,0.08597716733696596,0.08263854439908624,0.07942790299289659,0.07616188750490346,0.07438003691528026],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#287d8e\"},\"name\":\"9\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"38aeaf32-aa74-451d-8094-bde5f93975d2\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11052.295325497007,11212.705361919509,11368.864591182264,11398.78996374572,11425.824065083918,11374.755681704642,11321.373184735603,11274.453385553123,11206.414763213426,11152.830452841748,11103.737908148854,10987.81945397592,10971.696465389161,10850.543109804723,10728.169760230841,10715.360231738356,10614.329903571434,10533.835974010104,10505.237794759547,10368.71936512106],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#287d8e\"},\"name\":\"9\",\"type\":\"scatter\",\"uid\":\"0877cf20-5921-46a4-8bb7-0a002c7bce15\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47175098459955545,0.3533364312643379,0.27692864002604506,0.23227462876251695,0.1992339273085163,0.1752154543235442,0.15695860796865863,0.1425401542709221,0.12987043769720186,0.1194981244007122,0.11065799714369325,0.10503597469582807,0.09725717606234426,0.09312192856965566,0.08970996968103623,0.0840348909677989,0.08128474934784594,0.07834393294338478,0.0738203172283877,0.07253718289337063],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#238a8d\"},\"name\":\"10\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"9a50290f-3cd4-4ca7-95dc-0a14573d80f0\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11054.591787334148,11225.528282829357,11397.756567710436,11384.015365915013,11451.389274254923,11459.610588977725,11376.050029186565,11274.095516148473,11272.499217755421,11178.085961626613,11140.791754287642,11068.611912757306,11035.291654969596,10948.379622684975,10846.30843479845,10760.164548553728,10717.142639062211,10660.04707328942,10504.059452325992,10393.011181236432],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#238a8d\"},\"name\":\"10\",\"type\":\"scatter\",\"uid\":\"f37d01d2-0f86-4480-a40e-e856cd79179c\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46869175429362847,0.3489553241372833,0.272245622698486,0.23088331103266788,0.19396911644591475,0.16966303737984223,0.15365541714258069,0.14066857846930758,0.12625486648965414,0.11769844507310218,0.10873442822036551,0.10217357366795128,0.09428760780374013,0.08974201060071937,0.08619004289280512,0.08223115714542878,0.07778821666696925,0.07403971132288675,0.07307298001360511,0.07131405537195114],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#1f968b\"},\"name\":\"11\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f46e0992-b0a0-4bad-97f0-8a9bcb131327\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.824129738192,11205.221198116975,11257.276210948365,11249.982124832772,11346.90454878048,11369.200845314623,11327.975637400814,11265.70277970273,11242.69566867425,11125.713354976318,11085.643189312845,11003.766807453341,10952.925463047199,10818.865962225485,10751.827669918477,10622.890289468805,10581.153922616171,10457.765325669847,10406.863293593042,10293.690965995087],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#1f968b\"},\"name\":\"11\",\"type\":\"scatter\",\"uid\":\"6d95cc44-e8c8-42ec-abef-0b2c81aaf49b\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4745474662644775,0.35492209696573995,0.2908775211495747,0.24470866481882064,0.20504347418985933,0.17741364784201571,0.158531848563811,0.14501821946430396,0.13008713859723542,0.12233533943053944,0.11238724105660731,0.10569730424606064,0.09826037906138733,0.09469637422940755,0.0899277992037678,0.0877518224215559,0.08291661849234434,0.08063515139722367,0.07697286067066779,0.07517475455159717],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#20a386\"},\"name\":\"12\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"e63200e5-1ab0-4cc2-82e8-9787325392c4\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11033.00930341031,11148.879430055598,11221.615762493011,11261.57342812569,11263.081991396044,11194.36101620315,11176.653686173815,11119.362957181675,11160.897203210388,11060.87637020031,11002.1449565465,10869.256977805022,10791.657316178955,10690.963307625205,10679.12676315943,10633.713758296997,10563.593823093464,10475.666642067616,10394.48661058973,10307.337749004722],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#20a386\"},\"name\":\"12\",\"type\":\"scatter\",\"uid\":\"f929d7da-4b93-47c3-a5e4-72adb6f9f382\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47165370270082657,0.3578900265213915,0.2891560282862581,0.24083880524214488,0.207850463735504,0.183879329662469,0.16319167714340704,0.14789250815492916,0.1315299774179962,0.12372087214587789,0.11428466126416646,0.10883618535076436,0.10279474447387695,0.09766572146048448,0.09081568508209231,0.08593330607508279,0.08216375648793371,0.0791168136316962,0.07642694755200093,0.07384615302464889],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#29af7f\"},\"name\":\"13\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"1ca16111-032c-4aaa-8c4b-8eca516a722b\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11074.304190284523,11270.074704391543,11337.646753844456,11393.767844361715,11382.432493098264,11342.026259991246,11307.597681129108,11335.171775993951,11250.6392542343,11213.12741872705,11110.772199549234,11064.251343517122,11042.858520545049,10922.450884499984,10850.738987811244,10785.376592676303,10674.168878679426,10522.16989205271,10443.42359965938,10348.15135432266],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#29af7f\"},\"name\":\"13\",\"type\":\"scatter\",\"uid\":\"6522d0cc-d849-4ffd-b2aa-2c0ac8621322\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.467342777429912,0.3416024423087205,0.27910321174567143,0.23050913043389606,0.19851418434126283,0.1756663406326525,0.15711892203701325,0.13858010782473795,0.12834380644402385,0.1171226350779017,0.1100739293920589,0.10251441617453542,0.09467131931672483,0.09072574589902667,0.08637417761144375,0.08205309967814466,0.0790759363245614,0.07772849740381059,0.07510736536848106,0.07265137671612938],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#3dbc74\"},\"name\":\"14\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"6250beb8-9b30-430f-ad4f-0d51fcea4ef1\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11087.52557542617,11201.22705956107,11264.115790406604,11292.824638098962,11317.15699027003,11281.498582331276,11322.207028926732,11339.771680388227,11327.178998980202,11167.493221384164,11090.703318109807,10991.061715905907,10921.092013305804,10921.414809706115,10849.20591350587,10756.107814500603,10644.630217581205,10587.886446170434,10437.516867167407,10342.489678405149],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#3dbc74\"},\"name\":\"14\",\"type\":\"scatter\",\"uid\":\"0348ea19-7dfb-484c-ac28-e0e4c54678b6\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46565805426601725,0.3549669388200838,0.28907960083605916,0.2411840320437317,0.20445483555165378,0.18036279511146558,0.15735297031280943,0.13967623921493863,0.12582808284318311,0.1196681768510045,0.11138794680880144,0.1055940864813782,0.09923453037303112,0.09188690252759364,0.08696933388246794,0.08406815852725828,0.08086653912207462,0.07694310150792912,0.07586562190636095,0.07336532449072067],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#56c667\"},\"name\":\"15\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"462c36b3-b9e8-4ce4-b4c9-bcd6c05a9e71\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11068.046309185873,11150.1657775218,11259.927945300613,11258.671949226651,11266.893687156791,11275.907138982933,11188.304547244112,11219.76955522162,11200.243476725236,11135.251661568785,11027.9553934054,10929.698720441855,10834.157175493458,10882.486108740275,10770.225563673817,10675.837041470657,10617.65992960546,10487.333285002429,10387.978004645709,10300.551391623516],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#56c667\"},\"name\":\"15\",\"type\":\"scatter\",\"uid\":\"c3364bd3-cc1c-42ed-b9fb-f6fa53861253\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46932795796874316,0.3598819872397989,0.285055971973007,0.24047538038576205,0.20758977470283427,0.18247684789832205,0.16491868887500305,0.1456611303338732,0.130538472346563,0.12057559589816033,0.11339699738857592,0.10727304278755351,0.10171231167304949,0.09280065223916519,0.08879405804273395,0.0853581238153425,0.08131280053377832,0.07954659088876886,0.07699622231440464,0.07445860956230062],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#75d054\"},\"name\":\"16\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"ae72d9c9-eefc-4226-af27-6ba5f440e927\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10967.31969478168,11126.76319145041,11217.761301245822,11206.130309939237,11283.79566704848,11284.218727172118,11191.2011754941,11202.316834014986,11201.784297657408,11146.624926701426,11022.886564420533,10942.852665399472,10865.779600776847,10807.444186041452,10676.48415887533,10656.71918967577,10574.820743062714,10453.646767934868,10351.641526033645,10281.918724422572],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#75d054\"},\"name\":\"16\",\"type\":\"scatter\",\"uid\":\"0ffc5b02-67d9-460e-a0b5-bde791505b3f\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4839489656161168,0.3618062130877226,0.2909150276359095,0.24583547261525907,0.20725074455177855,0.18050061388388047,0.16415609857638205,0.14437984693241662,0.12930093466256506,0.11929659161564003,0.11340474191644224,0.10641542212233497,0.10029313585188744,0.09450661081431391,0.0912832933961531,0.08583573790565022,0.08193986649167614,0.07966061032772183,0.07725470102319104,0.07431405273739546],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#95d840\"},\"name\":\"17\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"b6f55400-3bba-4a9d-9cfb-185116510803\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11042.347172723761,11122.973037201844,11214.47667584529,11336.714091199528,11337.333756405553,11307.076261329576,11262.52884472405,11207.518823856928,11171.681766351456,11058.331353775344,11044.390776027116,10976.332366462924,10821.88548465819,10742.965724501102,10725.757122150602,10644.126114579372,10614.930269328564,10486.42793356228,10417.742463709848,10319.21159595824],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#95d840\"},\"name\":\"17\",\"type\":\"scatter\",\"uid\":\"ba0e3096-4d4a-46a6-8e5a-9e066028c60c\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4724737375219353,0.3620393874707304,0.28908163202480797,0.23539114185725982,0.20183083007143388,0.17676165818853307,0.15800650664756377,0.14388846834550909,0.1311422863027877,0.12300144214610709,0.11277399124395601,0.10539713038752788,0.10147886711690292,0.09667081343562228,0.09030685715510021,0.08580146888936005,0.0812276347565362,0.07912148699194729,0.07595030678843956,0.07373499783026392],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#bade28\"},\"name\":\"18\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"efc58e6e-388c-4fa7-adc8-b39033394f50\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11061.104094222763,11239.559981419903,11281.83666787449,11287.129683362742,11328.91317231443,11369.434920562888,11306.699883253495,11287.274234267423,11280.819840447972,11215.609120286588,11108.666525976647,11024.667197878096,10941.486197960681,10940.861997982878,10919.379371409235,10824.561557880075,10688.400325930346,10602.127733344892,10514.758739296245,10409.719642099037],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#bade28\"},\"name\":\"18\",\"type\":\"scatter\",\"uid\":\"dfe620d7-19c4-45f8-9251-fcb9362741f5\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4680443054089132,0.3472347580873458,0.2836200023918088,0.24021190278159577,0.204274700539618,0.17542992782803585,0.157115459554543,0.14083908157267244,0.12665973122712754,0.11702302794897913,0.11040994489760712,0.10363904300376084,0.0981613234509696,0.09078706955631384,0.08479711521083538,0.08159847452703323,0.07953048480286444,0.07630910821344586,0.07363747785845441,0.07179028233909275],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#dde318\"},\"name\":\"19\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"b9b7a027-12c5-4caa-80a6-160579180179\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#dde318\"},\"name\":\"19\",\"type\":\"scatter\",\"uid\":\"c1b52d9f-bf21-4d06-8e1f-7712003968f9\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#fde725\"},\"name\":\"20\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"6c66e381-fec4-475a-98a0-ca9c00229ca0\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#fde725\"},\"name\":\"20\",\"type\":\"scatter\",\"uid\":\"1ee155ae-d88d-42ee-a50b-ff051f915a2d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"}],                        {\"height\":450,\"legend\":{\"title\":{\"text\":\"Iterations\"},\"traceorder\":\"reversed\"},\"margin\":{\"b\":25,\"l\":10,\"pad\":0,\"r\":135,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,0.45],\"tickformat\":\"g\",\"title\":{\"text\":\"$\\\\text{Velocity}~[\\\\text{km}~\\\\text{s}^{-1}]$\"}},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.55,1.0],\"matches\":\"x\",\"tickformat\":\"g\",\"title\":{\"text\":\"$\\\\text{Velocity}~[\\\\text{km}~\\\\text{s}^{-1}]$\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{rad}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$W$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('2bbaa61e-6fdf-49e2-a33e-0ef4f1f2270c');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"47a017af-cfbd-487d-a299-9b2a7030da6d\" class=\"plotly-graph-div\" style=\"height:630px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"47a017af-cfbd-487d-a299-9b2a7030da6d\")) {                    Plotly.newPlot(                        \"47a017af-cfbd-487d-a299-9b2a7030da6d\",                        [{\"hovertemplate\":\"<b>%{y:.3f}</b> at X = %{x:,.0f}<extra>Inner Boundary Temperature</extra>\",\"hovertext\":\"text\",\"marker\":{\"color\":\"rgb(102, 197, 204)\"},\"mode\":\"lines\",\"name\":\"Inner<br>Boundary<br>Temperature\",\"type\":\"scatter\",\"uid\":\"b6fd7df6-b51e-4ddc-9c47-b154dbbf68c9\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x\",\"y\":[9933.951995919648,10703.211562422348,10673.712103958489,10635.953012231908,10638.406528771677,10650.201962584773,10645.954540809485,10642.04961793771,10636.106123877908,10654.31259429839,10628.189659670263,10644.054374080555,10653.542691388262,10647.276919600397,10638.875341023482,10655.125193761738,10655.56115672498,10636.535622734587,10641.692058870438,10650.463255529794],\"yaxis\":\"y\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"marker\":{\"color\":\"rgb(246, 207, 113)\"},\"mode\":\"lines\",\"name\":\"Emitted<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"120055d0-d393-441b-a331-628bf5cc703f\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[7.94217490576629e+42,1.0710516521093005e+43,1.0744260406037996e+43,1.0582996138891918e+43,1.0545940091430878e+43,1.0609681890774418e+43,1.0608322361748786e+43,1.0616467173322811e+43,1.0520605244141124e+43,1.0697420878067399e+43,1.0529798362530551e+43,1.0555093978401453e+43,1.0617727732344976e+43,1.062627715933488e+43,1.0528341253755922e+43,1.059103016026169e+43,1.0668824405561532e+43,1.057225256379625e+43,1.0557926285002873e+43,1.0607832431314582e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"marker\":{\"color\":\"rgb(248, 156, 116)\"},\"mode\":\"lines\",\"name\":\"Absorbed<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"9f032bed-c305-4aa3-a45f-d656c84e99f5\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[2.6585269987163907e+42,3.576326047128917e+42,3.3912529573296815e+42,3.351960855778322e+42,3.3988597390168757e+42,3.3980646035039864e+42,3.382148957209404e+42,3.3498688262362067e+42,3.4108734276587443e+42,3.334917848389675e+42,3.363215048559226e+42,3.419737826808236e+42,3.405731111443267e+42,3.3691331788887714e+42,3.41721250026907e+42,3.4445235238788086e+42,3.371808227073318e+42,3.3654653501429696e+42,3.40487735299688e+42,3.400790766998871e+42],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"marker\":{\"color\":\"rgb(220, 176, 242)\"},\"mode\":\"lines\",\"name\":\"Requested<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"4482362a-41bb-4575-b8ff-76fc4d461921\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.2f}%</b> at X = %{x:,.0f}\",\"marker\":{\"color\":\"rgb(135, 197, 95)\"},\"mode\":\"lines\",\"name\":\"Residual<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"498395d3-c7e5-454a-a4ff-7ac82b82908c\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x3\",\"y\":[-25.022636104275275,1.1116355710226051,1.4301915800245142,-0.09220874289084471,-0.44203291422789376,0.15971561705652318,0.1468811096714525,0.22377144619682712,-0.6812041849471281,0.9880073704063604,-0.59441740538123,-0.3556164952247293,0.2356716364643925,0.31638170721045433,-0.608173105315723,-0.016364310989694035,0.7180450300340984,-0.19363246486202446,-0.3288783680443794,0.1422559669511361],\"yaxis\":\"y3\"}],                        {\"height\":630,\"hoverlabel\":{\"align\":\"right\"},\"margin\":{\"b\":25,\"pad\":0,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"light\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"bgcolor\":\"#E5ECF6\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"zerolinewidth\":2}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x3\",\"range\":[0,21],\"showticklabels\":false},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x\",\"range\":[0,21],\"showticklabels\":false},\"xaxis3\":{\"anchor\":\"y3\",\"domain\":[0.0,1.0],\"dtick\":2,\"title\":{\"text\":\"$\\\\mbox{Iteration Number}$\"}},\"yaxis\":{\"anchor\":\"x\",\"automargin\":true,\"domain\":[0.79,1.0],\"exponentformat\":\"e\",\"nticks\":4,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{inner}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"automargin\":true,\"domain\":[0.29,0.71],\"exponentformat\":\"e\",\"nticks\":7,\"title\":{\"font\":{\"size\":13},\"text\":\"$\\\\text{Luminosity}~[\\\\text{erg s}^{-1}]$\"}},\"yaxis3\":{\"anchor\":\"x3\",\"automargin\":true,\"domain\":[0.0,0.21],\"nticks\":4,\"title\":{\"font\":{\"size\":12},\"text\":\"$~~\\\\text{Residual}\\\\\\\\\\\\text{Luminosity[%]}$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('47a017af-cfbd-487d-a299-9b2a7030da6d');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "sim = run_tardis(\n",
    "    \"tardis_example.yml\",\n",
    "    plasma_cmap= \"viridis\", \n",
    "    t_inner_luminosities_colors = ['rgb(102, 197, 204)',\n",
    "                         'rgb(246, 207, 113)',\n",
    "                         'rgb(248, 156, 116)',\n",
    "                         'rgb(220, 176, 242)',\n",
    "                         'rgb(135, 197, 95)'],\n",
    "    export_convergence_plots = True\n",
    ")"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "1f63c60a",
   "metadata": {},
   "source": [
    "## Changing the default layout"
   ]
  },
  {
   "cell_type": "markdown",
   "id": "3a3bdc2d",
   "metadata": {},
   "source": [
    "You can override the default layout by passing dictionaries as arguments in `t_inner_luminosities_config` and `plasma_plot_config`  in the `run_tardis` function. The dictionaries should have the format of `plotly.graph_objects.FigureWidget().to_dict()`. For more information on the structure of the dictionary, please see the [plotly documentation](https://plotly.com/python/figure-structure/). \n",
    "\n",
    "For sake of simplicity, all properties in the data dictionary are applied equally across all traces, meaning traces-specific properties can't be changed from the function. They however be changed after the simulation has finished, for example:\n",
    "```py\n",
    "sim.convergence_plots.t_inner_luminosities_plot.data[0].line.dash = \"dashdot\"\n",
    "```\n",
    "\n",
    "You can investigate more about the layout/data of any plots by calling `sim.convergence_plots.t_inner_luminosities_plot.layout` or `sim.convergence_plots.t_inner_luminosities_plot.data`. \n",
    "\n",
    "Here is an example:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "548990c8",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2021-10-14T16:51:31.673260Z",
     "iopub.status.busy": "2021-10-14T16:51:31.672572Z",
     "iopub.status.idle": "2021-10-14T16:52:08.656347Z",
     "shell.execute_reply": "2021-10-14T16:52:08.656855Z"
    },
    "scrolled": false
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f4b60f775adf4eb99a73beb241d0868a",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "TqdmHBox(children=(HTML(value='Iterations:', layout=Layout(width='6%')), FloatProgress(value=0.0, layout=Layou…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f13b949f6bb14150bd3306106bcbeb2d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "TqdmHBox(children=(HTML(value='Packets:   ', layout=Layout(width='6%')), FloatProgress(value=0.0, layout=Layou…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "ec438fca490341948efa8b4b33ef1b9f",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "VBox(children=(FigureWidget({\n",
       "    'data': [{'type': 'scatter', 'uid': '9e13d18c-c213-45ef-b996-981e20c68976', …"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"a12d4eef-6339-4566-8409-676822f2f706\" class=\"plotly-graph-div\" style=\"height:450px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"a12d4eef-6339-4566-8409-676822f2f706\")) {                    Plotly.newPlot(                        \"a12d4eef-6339-4566-8409-676822f2f706\",                        [{\"type\":\"scatter\",\"uid\":\"9e13d18c-c213-45ef-b996-981e20c68976\",\"xaxis\":\"x\",\"yaxis\":\"y\"},{\"type\":\"scatter\",\"uid\":\"b48040a9-4adb-4eb6-9709-f8f6fec6af16\",\"xaxis\":\"x2\",\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#000080\"},\"name\":\"1\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f3f04b40-a641-490f-9a25-307f785f6ac9\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[9926.501965464813,9911.63537753482,9896.813253389762,9882.035393850509,9867.301600925806,9852.611677803428,9837.96542884143,9823.362659559447,9808.803176630105,9794.286787870464,9779.813302233586,9765.382529800137,9750.99428177009,9736.64837045449,9722.344609267282,9708.082812717237,9693.862796399926,9679.684376989773,9665.547372232175,9651.451600935694],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\",\"<br>Emitted Luminosity: 7.942e+42<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 2.659e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-1\",\"line\":{\"color\":\"#000080\"},\"name\":\"1\",\"type\":\"scatter\",\"uid\":\"d574448b-9c81-49c5-bddd-42ba4c9e3651\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.40039163797855976,0.33245223097543924,0.2896679818236787,0.2577141002351936,0.23224568138195772,0.211204659222757,0.19341188222536587,0.17811401706296348,0.16479446041469908,0.15308090298851573,0.14269498356756605,0.13342261532969785,0.12509541040763922,0.11757848682757521,0.11076215248105115,0.10455605179542055,0.09888493580965113,0.09368553636653854,0.08890421153628925,0.08449514228457095],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#0000bd\"},\"name\":\"2\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"985d7f49-ed2b-48ee-b151-94c1801b7b4d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10140.644658439542,10163.140953757294,10199.392781222336,10228.793058184721,10271.14775928106,10224.009713529731,10228.732523936606,10216.98049975123,10217.783033963955,10193.706231603874,10148.77879424612,10080.136790247385,10031.646882137076,10030.254549667037,9988.12702379364,9874.634222100456,9844.474903130327,9776.381862231508,9680.562581778317,9611.593058427065],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\",\"<br>Emitted Luminosity: 1.071e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.576e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-2\",\"line\":{\"color\":\"#0000bd\"},\"name\":\"2\",\"type\":\"scatter\",\"uid\":\"882b142d-529d-4587-a868-36c4391708f7\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5074939829206923,0.39593831162891974,0.32150485888655256,0.26573787630888046,0.2236515966575156,0.19686688849248643,0.1746427953806121,0.15625093331810624,0.13946942342362406,0.12759533918829524,0.11697794966442067,0.10915672831486313,0.10296463647641346,0.09515332126864076,0.08981745405810744,0.08689548233577285,0.08198790793189142,0.07881149990806682,0.07637264409196345,0.07345198061495406],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#0000fa\"},\"name\":\"3\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"a54d3a9b-4ec5-430c-ae53-08d5d197ca4a\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10821.384716452621,10824.07375074843,10898.794282582267,10931.581728038504,10962.883353030435,10956.472449386303,10935.661811838689,10896.394485335457,10868.778286813804,10846.86064742898,10799.242899977486,10741.078256171444,10679.03654492254,10616.6413627693,10548.485755133186,10483.027318852863,10402.58849317583,10353.528838881304,10280.790364670062,10205.89807450607],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\",\"<br>Emitted Luminosity: 1.074e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.391e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-3\",\"line\":{\"color\":\"#0000fa\"},\"name\":\"3\",\"type\":\"scatter\",\"uid\":\"d38c716d-5869-4704-9d30-54e9a57fdd1b\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.5246621760292516,0.41191697242104813,0.33082428419284166,0.2739415803649503,0.23102276356532733,0.20265771066458735,0.18068103823778522,0.16215467464075065,0.14618948104529478,0.13362668956992607,0.12450448547982709,0.11605105087549335,0.10925211388307239,0.10302987363746915,0.09831778993852412,0.0932577131276202,0.08908435787384879,0.08446805448195224,0.08117712884118686,0.07815148665239906],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#0022ff\"},\"name\":\"4\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"91b61779-1e58-48a8-a2c9-cc8bc0f28d83\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11001.634918288773,11064.199689011095,11146.787545057517,11182.280653331733,11189.736123692379,11179.454369423816,11213.79207405269,11157.651049771417,11091.366692176987,11032.681911673413,10951.71311170724,10882.347593647743,10815.56574149097,10758.062388449993,10666.645789560242,10589.476597771141,10519.279070600585,10489.380846260961,10394.331364500693,10280.44535660762],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\",\"<br>Emitted Luminosity: 1.058e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.352e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-4\",\"line\":{\"color\":\"#0022ff\"},\"name\":\"4\",\"type\":\"scatter\",\"uid\":\"4441a4a1-115f-4bf4-ab12-4dc0598bd06f\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.48255611027402595,0.37531673900188744,0.3008854405436438,0.24970650566435726,0.21504788747697892,0.1889210232599808,0.16485989155704653,0.14922567218546676,0.1373433490366653,0.1270628239280638,0.11816510452204829,0.11046612213518453,0.10408751562676459,0.09837704095780829,0.09380107799147919,0.08948233963910264,0.08532986022143939,0.08049857949608492,0.07819235373949822,0.07599589756382483],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#0057ff\"},\"name\":\"5\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"5879d087-552a-4a83-ac1e-5d96fce7e7f9\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.69813331972,11131.435799441577,11213.984633035107,11254.938537458936,11264.10756107921,11231.114026250594,11180.234767099426,11161.43757582825,11095.861090734456,11098.458607564848,11036.771405771051,10960.49690639981,10968.575819463373,10890.828989905996,10799.341137335274,10659.853383147958,10549.231623432072,10506.788250185065,10398.595227817385,10289.349894730598],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\",\"<br>Emitted Luminosity: 1.055e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.399e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-5\",\"line\":{\"color\":\"#0057ff\"},\"name\":\"5\",\"type\":\"scatter\",\"uid\":\"8ae1e102-8d71-4554-afe4-f4d7097ad4e2\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46875384769180994,0.3582440793604906,0.2859963458991618,0.23841076673448683,0.20840515079453156,0.18245979900971618,0.1638530282293532,0.14657197302070762,0.13503875104453528,0.12203984302262225,0.11334205862439253,0.10619057923554849,0.09765445785021042,0.09265039020379297,0.08856994824064786,0.0861030166939687,0.08350964472774987,0.07926097434257318,0.07675258324197402,0.07475268831395629],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#008dff\"},\"name\":\"6\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"c590b3a4-3bfd-426e-ad95-77088f08a0cf\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11004.024489659887,11119.370907976154,11195.435272777357,11259.07218492983,11285.20780804646,11285.17736284529,11257.669785381573,11225.435571936492,11186.445768225169,11099.126705981142,11029.754124780751,10939.09235294023,10877.977505280129,10799.952863140219,10803.94962659834,10716.294187213076,10608.39027776731,10536.800302652608,10451.345002096903,10351.499433918842],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.398e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-6\",\"line\":{\"color\":\"#008dff\"},\"name\":\"6\",\"type\":\"scatter\",\"uid\":\"137cc280-d04a-4169-b184-f2f41986a3a2\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47879511389335816,0.36722911837191247,0.2926208974449371,0.24239288815881765,0.20444578448470932,0.17802906434287452,0.15880728036632202,0.14352699270970695,0.13113431023478964,0.12123492206018885,0.11293848121019129,0.107206115377895,0.09996151019829129,0.09452711171505655,0.08773741567449585,0.0838574125841496,0.08091696481124855,0.07741620755854674,0.07503066951006154,0.0727305286162828],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#00c3ff\"},\"name\":\"7\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"a1a5280d-4115-447b-af6d-d741f28b1e7d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11049.228732355552,11156.739354515785,11233.159171838806,11257.86819871853,11259.221213382081,11218.728487793938,11177.383540027478,11170.932602943105,11091.339644892223,11058.83258870618,11086.886472116763,10967.000400044035,10888.705512509965,10859.351173962054,10794.116212447141,10665.940454226306,10614.036765336794,10560.167635600494,10433.600109025549,10347.135454231406],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.382e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-7\",\"line\":{\"color\":\"#00c3ff\"},\"name\":\"7\",\"type\":\"scatter\",\"uid\":\"935b4b0e-3e41-45bc-ab9e-d2cad19a0b99\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4697400940159998,0.3588700697047573,0.29077776563828756,0.2443651184699209,0.20776673425141715,0.1852074960564398,0.16487114788798946,0.14711076442391682,0.13525030370898636,0.12403257789506693,0.11208234573021662,0.10708808842987298,0.1008199099410747,0.09351009430956675,0.08797758265708822,0.08557481001143187,0.08167863229931253,0.07764065281949213,0.07578960072572662,0.07324774090303579],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#0ff8e8\"},\"name\":\"8\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"a8a2c59e-8215-4d9a-907b-afa44cd973f5\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11037.08503719401,11149.996498693195,11245.895992066266,11293.021085350518,11348.844546340542,11303.81450750131,11275.886160361555,11193.561854480458,11139.762040353016,11142.50167244028,11052.1571050735,10947.278343765189,10930.67339710046,10870.232618754231,10717.538511627446,10653.978725318402,10563.0762100547,10483.387471111888,10423.15401494719,10305.26962980183],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.35e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-8\",\"line\":{\"color\":\"#0ff8e8\"},\"name\":\"8\",\"type\":\"scatter\",\"uid\":\"6fd10268-4b33-4a0a-92c9-043b9434a23d\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46951709287046905,0.3558132377939077,0.28344389342857873,0.23679038121368734,0.2006318674457632,0.17752655689561797,0.15896810063770853,0.14566983788022744,0.13249513450931652,0.11945436911075241,0.11202516442423788,0.10653028310041686,0.09880763358506521,0.09250430944965742,0.0904904576740684,0.08597716733696596,0.08263854439908624,0.07942790299289659,0.07616188750490346,0.07438003691528026],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#3affbc\"},\"name\":\"9\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f6d3d437-5b36-4616-baf5-ae824facd9aa\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11052.295325497007,11212.705361919509,11368.864591182264,11398.78996374572,11425.824065083918,11374.755681704642,11321.373184735603,11274.453385553123,11206.414763213426,11152.830452841748,11103.737908148854,10987.81945397592,10971.696465389161,10850.543109804723,10728.169760230841,10715.360231738356,10614.329903571434,10533.835974010104,10505.237794759547,10368.71936512106],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\",\"<br>Emitted Luminosity: 1.052e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.411e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-9\",\"line\":{\"color\":\"#3affbc\"},\"name\":\"9\",\"type\":\"scatter\",\"uid\":\"86ab89ea-643e-4a3d-89c1-30eace59893b\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47175098459955545,0.3533364312643379,0.27692864002604506,0.23227462876251695,0.1992339273085163,0.1752154543235442,0.15695860796865863,0.1425401542709221,0.12987043769720186,0.1194981244007122,0.11065799714369325,0.10503597469582807,0.09725717606234426,0.09312192856965566,0.08970996968103623,0.0840348909677989,0.08128474934784594,0.07834393294338478,0.0738203172283877,0.07253718289337063],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#66ff91\"},\"name\":\"10\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"f60a7490-3b8b-4f0d-a3b7-d01d895362a2\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11054.591787334148,11225.528282829357,11397.756567710436,11384.015365915013,11451.389274254923,11459.610588977725,11376.050029186565,11274.095516148473,11272.499217755421,11178.085961626613,11140.791754287642,11068.611912757306,11035.291654969596,10948.379622684975,10846.30843479845,10760.164548553728,10717.142639062211,10660.04707328942,10504.059452325992,10393.011181236432],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\",\"<br>Emitted Luminosity: 1.07e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.335e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-10\",\"line\":{\"color\":\"#66ff91\"},\"name\":\"10\",\"type\":\"scatter\",\"uid\":\"921c0492-47b9-4368-8e72-d9a4af25dbe1\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46869175429362847,0.3489553241372833,0.272245622698486,0.23088331103266788,0.19396911644591475,0.16966303737984223,0.15365541714258069,0.14066857846930758,0.12625486648965414,0.11769844507310218,0.10873442822036551,0.10217357366795128,0.09428760780374013,0.08974201060071937,0.08619004289280512,0.08223115714542878,0.07778821666696925,0.07403971132288675,0.07307298001360511,0.07131405537195114],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#91ff66\"},\"name\":\"11\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"9b92d5dc-f8a9-410b-8b97-7c53c2d144e1\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11038.824129738192,11205.221198116975,11257.276210948365,11249.982124832772,11346.90454878048,11369.200845314623,11327.975637400814,11265.70277970273,11242.69566867425,11125.713354976318,11085.643189312845,11003.766807453341,10952.925463047199,10818.865962225485,10751.827669918477,10622.890289468805,10581.153922616171,10457.765325669847,10406.863293593042,10293.690965995087],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.363e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-11\",\"line\":{\"color\":\"#91ff66\"},\"name\":\"11\",\"type\":\"scatter\",\"uid\":\"1a079318-7db1-416b-aa40-25a36abdb44e\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4745474662644775,0.35492209696573995,0.2908775211495747,0.24470866481882064,0.20504347418985933,0.17741364784201571,0.158531848563811,0.14501821946430396,0.13008713859723542,0.12233533943053944,0.11238724105660731,0.10569730424606064,0.09826037906138733,0.09469637422940755,0.0899277992037678,0.0877518224215559,0.08291661849234434,0.08063515139722367,0.07697286067066779,0.07517475455159717],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#bcff3a\"},\"name\":\"12\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"c218f887-c853-4078-8e1e-9337cec4ad94\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11033.00930341031,11148.879430055598,11221.615762493011,11261.57342812569,11263.081991396044,11194.36101620315,11176.653686173815,11119.362957181675,11160.897203210388,11060.87637020031,11002.1449565465,10869.256977805022,10791.657316178955,10690.963307625205,10679.12676315943,10633.713758296997,10563.593823093464,10475.666642067616,10394.48661058973,10307.337749004722],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.42e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-12\",\"line\":{\"color\":\"#bcff3a\"},\"name\":\"12\",\"type\":\"scatter\",\"uid\":\"bf30958d-11ed-4348-a5cc-dbe75e95d632\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.47165370270082657,0.3578900265213915,0.2891560282862581,0.24083880524214488,0.207850463735504,0.183879329662469,0.16319167714340704,0.14789250815492916,0.1315299774179962,0.12372087214587789,0.11428466126416646,0.10883618535076436,0.10279474447387695,0.09766572146048448,0.09081568508209231,0.08593330607508279,0.08216375648793371,0.0791168136316962,0.07642694755200093,0.07384615302464889],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#e8ff0f\"},\"name\":\"13\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"1529b45b-9459-4e4f-8148-96fffe434806\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11074.304190284523,11270.074704391543,11337.646753844456,11393.767844361715,11382.432493098264,11342.026259991246,11307.597681129108,11335.171775993951,11250.6392542343,11213.12741872705,11110.772199549234,11064.251343517122,11042.858520545049,10922.450884499984,10850.738987811244,10785.376592676303,10674.168878679426,10522.16989205271,10443.42359965938,10348.15135432266],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\",\"<br>Emitted Luminosity: 1.062e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.406e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-13\",\"line\":{\"color\":\"#e8ff0f\"},\"name\":\"13\",\"type\":\"scatter\",\"uid\":\"d1025351-a274-42b0-9587-cee8183dd5bf\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.467342777429912,0.3416024423087205,0.27910321174567143,0.23050913043389606,0.19851418434126283,0.1756663406326525,0.15711892203701325,0.13858010782473795,0.12834380644402385,0.1171226350779017,0.1100739293920589,0.10251441617453542,0.09467131931672483,0.09072574589902667,0.08637417761144375,0.08205309967814466,0.0790759363245614,0.07772849740381059,0.07510736536848106,0.07265137671612938],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#ffd500\"},\"name\":\"14\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"04fe2040-69fa-477a-b493-e8dc6475f38e\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11087.52557542617,11201.22705956107,11264.115790406604,11292.824638098962,11317.15699027003,11281.498582331276,11322.207028926732,11339.771680388227,11327.178998980202,11167.493221384164,11090.703318109807,10991.061715905907,10921.092013305804,10921.414809706115,10849.20591350587,10756.107814500603,10644.630217581205,10587.886446170434,10437.516867167407,10342.489678405149],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\",\"<br>Emitted Luminosity: 1.063e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.369e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-14\",\"line\":{\"color\":\"#ffd500\"},\"name\":\"14\",\"type\":\"scatter\",\"uid\":\"083a7485-717b-47e4-bbce-736baf43a1a1\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46565805426601725,0.3549669388200838,0.28907960083605916,0.2411840320437317,0.20445483555165378,0.18036279511146558,0.15735297031280943,0.13967623921493863,0.12582808284318311,0.1196681768510045,0.11138794680880144,0.1055940864813782,0.09923453037303112,0.09188690252759364,0.08696933388246794,0.08406815852725828,0.08086653912207462,0.07694310150792912,0.07586562190636095,0.07336532449072067],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#ffa400\"},\"name\":\"15\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"aa89856e-3845-4e8a-b7fa-fb2eed397f5a\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11068.046309185873,11150.1657775218,11259.927945300613,11258.671949226651,11266.893687156791,11275.907138982933,11188.304547244112,11219.76955522162,11200.243476725236,11135.251661568785,11027.9553934054,10929.698720441855,10834.157175493458,10882.486108740275,10770.225563673817,10675.837041470657,10617.65992960546,10487.333285002429,10387.978004645709,10300.551391623516],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\",\"<br>Emitted Luminosity: 1.053e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.417e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-15\",\"line\":{\"color\":\"#ffa400\"},\"name\":\"15\",\"type\":\"scatter\",\"uid\":\"87f481ec-051b-47cd-a41f-ef9aeedef2e4\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.46932795796874316,0.3598819872397989,0.285055971973007,0.24047538038576205,0.20758977470283427,0.18247684789832205,0.16491868887500305,0.1456611303338732,0.130538472346563,0.12057559589816033,0.11339699738857592,0.10727304278755351,0.10171231167304949,0.09280065223916519,0.08879405804273395,0.0853581238153425,0.08131280053377832,0.07954659088876886,0.07699622231440464,0.07445860956230062],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#ff7200\"},\"name\":\"16\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"32d03251-b89c-4a7f-b3dd-098bc8f22496\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[10967.31969478168,11126.76319145041,11217.761301245822,11206.130309939237,11283.79566704848,11284.218727172118,11191.2011754941,11202.316834014986,11201.784297657408,11146.624926701426,11022.886564420533,10942.852665399472,10865.779600776847,10807.444186041452,10676.48415887533,10656.71918967577,10574.820743062714,10453.646767934868,10351.641526033645,10281.918724422572],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\",\"<br>Emitted Luminosity: 1.059e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.445e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-16\",\"line\":{\"color\":\"#ff7200\"},\"name\":\"16\",\"type\":\"scatter\",\"uid\":\"bcaef199-98b6-4121-9cc3-2206d3f2d199\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4839489656161168,0.3618062130877226,0.2909150276359095,0.24583547261525907,0.20725074455177855,0.18050061388388047,0.16415609857638205,0.14437984693241662,0.12930093466256506,0.11929659161564003,0.11340474191644224,0.10641542212233497,0.10029313585188744,0.09450661081431391,0.0912832933961531,0.08583573790565022,0.08193986649167614,0.07966061032772183,0.07725470102319104,0.07431405273739546],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#ff4000\"},\"name\":\"17\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"fdf8cca2-4c90-4bc9-9761-ce5325c1f220\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11042.347172723761,11122.973037201844,11214.47667584529,11336.714091199528,11337.333756405553,11307.076261329576,11262.52884472405,11207.518823856928,11171.681766351456,11058.331353775344,11044.390776027116,10976.332366462924,10821.88548465819,10742.965724501102,10725.757122150602,10644.126114579372,10614.930269328564,10486.42793356228,10417.742463709848,10319.21159595824],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\",\"<br>Emitted Luminosity: 1.067e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.372e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-17\",\"line\":{\"color\":\"#ff4000\"},\"name\":\"17\",\"type\":\"scatter\",\"uid\":\"52a5342c-cdea-44c5-a8a3-9af3dd6de21b\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4724737375219353,0.3620393874707304,0.28908163202480797,0.23539114185725982,0.20183083007143388,0.17676165818853307,0.15800650664756377,0.14388846834550909,0.1311422863027877,0.12300144214610709,0.11277399124395601,0.10539713038752788,0.10147886711690292,0.09667081343562228,0.09030685715510021,0.08580146888936005,0.0812276347565362,0.07912148699194729,0.07595030678843956,0.07373499783026392],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#fa0e00\"},\"name\":\"18\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"672b9c86-953e-4fb6-99dd-3d78d79e9d58\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11061.104094222763,11239.559981419903,11281.83666787449,11287.129683362742,11328.91317231443,11369.434920562888,11306.699883253495,11287.274234267423,11280.819840447972,11215.609120286588,11108.666525976647,11024.667197878096,10941.486197960681,10940.861997982878,10919.379371409235,10824.561557880075,10688.400325930346,10602.127733344892,10514.758739296245,10409.719642099037],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\",\"<br>Emitted Luminosity: 1.057e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.365e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-18\",\"line\":{\"color\":\"#fa0e00\"},\"name\":\"18\",\"type\":\"scatter\",\"uid\":\"7acc5f5c-61c9-4f8c-b9bb-d82a9244155a\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4680443054089132,0.3472347580873458,0.2836200023918088,0.24021190278159577,0.204274700539618,0.17542992782803585,0.157115459554543,0.14083908157267244,0.12665973122712754,0.11702302794897913,0.11040994489760712,0.10363904300376084,0.0981613234509696,0.09078706955631384,0.08479711521083538,0.08159847452703323,0.07953048480286444,0.07630910821344586,0.07363747785845441,0.07179028233909275],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#bd0000\"},\"name\":\"19\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"7269edfb-5075-4b00-a852-e26bdc7b2b60\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\",\"<br>Emitted Luminosity: 1.056e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.405e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-19\",\"line\":{\"color\":\"#bd0000\"},\"name\":\"19\",\"type\":\"scatter\",\"uid\":\"70273b40-d671-426e-9a98-24f709463975\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#800000\"},\"name\":\"20\",\"showlegend\":false,\"type\":\"scatter\",\"uid\":\"84a29707-19d2-4b5f-9507-627431962841\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x\",\"y\":[11069.193823700834,11144.033206219898,11213.390462097448,11305.72853175652,11285.266184353555,11323.7819744027,11271.17366687512,11265.745450084161,11172.683228067404,11091.044477502059,11030.940701284266,10992.910316594745,10907.845154495471,10860.3438851032,10754.598368722307,10675.606608814991,10611.90884863864,10526.402210396021,10470.935047886089,10349.22810317362],\"yaxis\":\"y\"},{\"customdata\":[\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\",\"<br>Emitted Luminosity: 1.061e+43<br>Requested Luminosity: 1.059e+43<br>Absorbed Luminosity: 3.401e+42\"],\"hovertemplate\":\"<b>Y</b>: %{y:.3f} at <b>X</b> = %{x:,.0f}%{customdata}\",\"legendgroup\":\"group-20\",\"line\":{\"color\":\"#800000\"},\"name\":\"20\",\"type\":\"scatter\",\"uid\":\"d7d2201c-5cdc-4de6-b224-6a6e9fe8c8ce\",\"x\":[11000.0,11450.000000000002,11900.000000000002,12350.000000000002,12800.000000000002,13250.000000000002,13700.000000000002,14150.000000000002,14600.000000000002,15050.000000000002,15500.000000000002,15950.000000000002,16400.0,16850.0,17300.0,17750.0,18200.0,18650.0,19100.0,19550.0,20000.0],\"xaxis\":\"x2\",\"y\":[0.4639715092825944,0.3556123749638903,0.28682866589375816,0.23621024823808645,0.2060826346871983,0.17691635421177018,0.15906281669924688,0.14202949708480922,0.13175074456827993,0.1221220567057581,0.11300865795976021,0.10531621306129164,0.09917457589453398,0.09274654004815944,0.08897179267639928,0.08478992203293945,0.081350822668129,0.07813940112787308,0.07443394184577531,0.07303258810237377],\"yaxis\":\"y2\"}],                        {\"height\":450,\"legend\":{\"title\":{\"text\":\"Iterations\"},\"traceorder\":\"reversed\"},\"margin\":{\"b\":25,\"l\":10,\"pad\":0,\"r\":135,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"rgb(51,51,51)\"},\"error_y\":{\"color\":\"rgb(51,51,51)\"},\"marker\":{\"line\":{\"color\":\"rgb(237,237,237)\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"rgb(237,237,237)\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"rgb(51,51,51)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(51,51,51)\"},\"baxis\":{\"endlinecolor\":\"rgb(51,51,51)\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"rgb(51,51,51)\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"colorscale\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"colorscale\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"colorscale\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"colorscale\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"colorscale\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"},\"colorscale\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"rgb(237,237,237)\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"rgb(217,217,217)\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"tickcolor\":\"rgb(237,237,237)\",\"ticklen\":6,\"ticks\":\"inside\"}},\"colorscale\":{\"sequential\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]],\"sequentialminus\":[[0,\"rgb(20,44,66)\"],[1,\"rgb(90,179,244)\"]]},\"colorway\":[\"#F8766D\",\"#A3A500\",\"#00BF7D\",\"#00B0F6\",\"#E76BF3\"],\"font\":{\"color\":\"rgb(51,51,51)\"},\"geo\":{\"bgcolor\":\"white\",\"lakecolor\":\"white\",\"landcolor\":\"rgb(237,237,237)\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"white\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"rgb(237,237,237)\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\"},\"bgcolor\":\"rgb(237,237,237)\",\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"rgb(237,237,237)\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\",\"zerolinecolor\":\"white\"},\"yaxis\":{\"backgroundcolor\":\"rgb(237,237,237)\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\",\"zerolinecolor\":\"white\"},\"zaxis\":{\"backgroundcolor\":\"rgb(237,237,237)\",\"gridcolor\":\"white\",\"gridwidth\":2,\"linecolor\":\"white\",\"showbackground\":true,\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\",\"zerolinecolor\":\"white\"}},\"shapedefaults\":{\"fillcolor\":\"black\",\"line\":{\"width\":0},\"opacity\":0.3},\"ternary\":{\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\"},\"bgcolor\":\"rgb(237,237,237)\",\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\"}},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\"},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showgrid\":true,\"tickcolor\":\"rgb(51,51,51)\",\"ticks\":\"outside\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\"}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,0.45],\"nticks\":20,\"tickformat\":\"g\",\"title\":{\"text\":\"$\\\\text{Velocity}~[\\\\text{km}~\\\\text{s}^{-1}]$\"}},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.55,1.0],\"matches\":\"x\",\"nticks\":20,\"tickformat\":\"g\",\"title\":{\"text\":\"new changed title of x axis2\"}},\"yaxis\":{\"anchor\":\"x\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{rad}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"domain\":[0.0,1.0],\"nticks\":15,\"tickformat\":\"g\",\"title\":{\"text\":\"$W$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('a12d4eef-6339-4566-8409-676822f2f706');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "        <script type=\"text/javascript\">\n",
       "        window.PlotlyConfig = {MathJaxConfig: 'local'};\n",
       "        if (window.MathJax) {MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}\n",
       "        if (typeof require !== 'undefined') {\n",
       "        require.undef(\"plotly\");\n",
       "        requirejs.config({\n",
       "            paths: {\n",
       "                'plotly': ['https://cdn.plot.ly/plotly-2.4.2.min']\n",
       "            }\n",
       "        });\n",
       "        require(['plotly'], function(Plotly) {\n",
       "            window._Plotly = Plotly;\n",
       "        });\n",
       "        }\n",
       "        </script>\n",
       "        "
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>                            <div id=\"6aa18f35-9b6f-4bc6-9bb1-8a7577d262a8\" class=\"plotly-graph-div\" style=\"height:630px; width:100%;\"></div>            <script type=\"text/javascript\">                require([\"plotly\"], function(Plotly) {                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"6aa18f35-9b6f-4bc6-9bb1-8a7577d262a8\")) {                    Plotly.newPlot(                        \"6aa18f35-9b6f-4bc6-9bb1-8a7577d262a8\",                        [{\"hovertemplate\":\"<b>%{y:.3f}</b> at X = %{x:,.0f}<extra>Inner Boundary Temperature</extra>\",\"hovertext\":\"text\",\"line\":{\"dash\":\"dot\"},\"mode\":\"lines+markers\",\"name\":\"Inner<br>Boundary<br>Temperature\",\"type\":\"scatter\",\"uid\":\"303b70e6-556d-4cff-96a8-8eb10ad7232c\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x\",\"y\":[9933.951995919648,10703.211562422348,10673.712103958489,10635.953012231908,10638.406528771677,10650.201962584773,10645.954540809485,10642.04961793771,10636.106123877908,10654.31259429839,10628.189659670263,10644.054374080555,10653.542691388262,10647.276919600397,10638.875341023482,10655.125193761738,10655.56115672498,10636.535622734587,10641.692058870438,10650.463255529794],\"yaxis\":\"y\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"line\":{\"dash\":\"dot\"},\"mode\":\"lines+markers\",\"name\":\"Emitted<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"3a230168-42f6-488a-8e4a-8a86d70a9c2e\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[7.94217490576629e+42,1.0710516521093005e+43,1.0744260406037996e+43,1.0582996138891918e+43,1.0545940091430878e+43,1.0609681890774418e+43,1.0608322361748786e+43,1.0616467173322811e+43,1.0520605244141124e+43,1.0697420878067399e+43,1.0529798362530551e+43,1.0555093978401453e+43,1.0617727732344976e+43,1.062627715933488e+43,1.0528341253755922e+43,1.059103016026169e+43,1.0668824405561532e+43,1.057225256379625e+43,1.0557926285002873e+43,1.0607832431314582e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"line\":{\"dash\":\"dot\"},\"mode\":\"lines+markers\",\"name\":\"Absorbed<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"acd8c0a4-5e81-4d37-b6dd-cb04d44c0225\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[2.6585269987163907e+42,3.576326047128917e+42,3.3912529573296815e+42,3.351960855778322e+42,3.3988597390168757e+42,3.3980646035039864e+42,3.382148957209404e+42,3.3498688262362067e+42,3.4108734276587443e+42,3.334917848389675e+42,3.363215048559226e+42,3.419737826808236e+42,3.405731111443267e+42,3.3691331788887714e+42,3.41721250026907e+42,3.4445235238788086e+42,3.371808227073318e+42,3.3654653501429696e+42,3.40487735299688e+42,3.400790766998871e+42],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.4g}</b><br>at X = %{x}<br>\",\"line\":{\"dash\":\"dot\"},\"mode\":\"lines+markers\",\"name\":\"Requested<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"1efd6566-8760-421d-8801-ab08aab8612d\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x2\",\"y\":[1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43,1.0592763593038458e+43],\"yaxis\":\"y2\"},{\"hovertemplate\":\"<b>%{y:.2f}%</b> at X = %{x:,.0f}\",\"line\":{\"dash\":\"dot\"},\"mode\":\"lines+markers\",\"name\":\"Residual<br>Luminosity\",\"type\":\"scatter\",\"uid\":\"b211b254-d5ed-4b32-8af0-9e40af55145a\",\"x\":[1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20],\"xaxis\":\"x3\",\"y\":[-25.022636104275275,1.1116355710226051,1.4301915800245142,-0.09220874289084471,-0.44203291422789376,0.15971561705652318,0.1468811096714525,0.22377144619682712,-0.6812041849471281,0.9880073704063604,-0.59441740538123,-0.3556164952247293,0.2356716364643925,0.31638170721045433,-0.608173105315723,-0.016364310989694035,0.7180450300340984,-0.19363246486202446,-0.3288783680443794,0.1422559669511361],\"yaxis\":\"y3\"}],                        {\"height\":630,\"hoverlabel\":{\"align\":\"right\"},\"hovermode\":\"x\",\"margin\":{\"b\":25,\"pad\":0,\"t\":25},\"template\":{\"data\":{\"bar\":[{\"error_x\":{\"color\":\"#f2f5fa\"},\"error_y\":{\"color\":\"#f2f5fa\"},\"marker\":{\"line\":{\"color\":\"rgb(17,17,17)\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"rgb(17,17,17)\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#A2B1C6\",\"gridcolor\":\"#506784\",\"linecolor\":\"#506784\",\"minorgridcolor\":\"#506784\",\"startlinecolor\":\"#A2B1C6\"},\"baxis\":{\"endlinecolor\":\"#A2B1C6\",\"gridcolor\":\"#506784\",\"linecolor\":\"#506784\",\"minorgridcolor\":\"#506784\",\"startlinecolor\":\"#A2B1C6\"},\"type\":\"carpet\"}],\"choropleth\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"choropleth\"}],\"contour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"contour\"}],\"contourcarpet\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"contourcarpet\"}],\"heatmap\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmap\"}],\"heatmapgl\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"heatmapgl\"}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"histogram2d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2d\"}],\"histogram2dcontour\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"histogram2dcontour\"}],\"mesh3d\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"type\":\"mesh3d\"}],\"parcoords\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"parcoords\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}],\"scatter\":[{\"marker\":{\"line\":{\"color\":\"#283442\"}},\"type\":\"scatter\"}],\"scatter3d\":[{\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatter3d\"}],\"scattercarpet\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattercarpet\"}],\"scattergeo\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattergeo\"}],\"scattergl\":[{\"marker\":{\"line\":{\"color\":\"#283442\"}},\"type\":\"scattergl\"}],\"scattermapbox\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scattermapbox\"}],\"scatterpolar\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolar\"}],\"scatterpolargl\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterpolargl\"}],\"scatterternary\":[{\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"type\":\"scatterternary\"}],\"surface\":[{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"type\":\"surface\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#506784\"},\"line\":{\"color\":\"rgb(17,17,17)\"}},\"header\":{\"fill\":{\"color\":\"#2a3f5f\"},\"line\":{\"color\":\"rgb(17,17,17)\"}},\"type\":\"table\"}]},\"layout\":{\"annotationdefaults\":{\"arrowcolor\":\"#f2f5fa\",\"arrowhead\":0,\"arrowwidth\":1},\"autotypenumbers\":\"strict\",\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]],\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]},\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#f2f5fa\"},\"geo\":{\"bgcolor\":\"rgb(17,17,17)\",\"lakecolor\":\"rgb(17,17,17)\",\"landcolor\":\"rgb(17,17,17)\",\"showlakes\":true,\"showland\":true,\"subunitcolor\":\"#506784\"},\"hoverlabel\":{\"align\":\"left\"},\"hovermode\":\"closest\",\"mapbox\":{\"style\":\"dark\"},\"paper_bgcolor\":\"rgb(17,17,17)\",\"plot_bgcolor\":\"rgb(17,17,17)\",\"polar\":{\"angularaxis\":{\"gridcolor\":\"#506784\",\"linecolor\":\"#506784\",\"ticks\":\"\"},\"bgcolor\":\"rgb(17,17,17)\",\"radialaxis\":{\"gridcolor\":\"#506784\",\"linecolor\":\"#506784\",\"ticks\":\"\"}},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"rgb(17,17,17)\",\"gridcolor\":\"#506784\",\"gridwidth\":2,\"linecolor\":\"#506784\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"#C8D4E3\"},\"yaxis\":{\"backgroundcolor\":\"rgb(17,17,17)\",\"gridcolor\":\"#506784\",\"gridwidth\":2,\"linecolor\":\"#506784\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"#C8D4E3\"},\"zaxis\":{\"backgroundcolor\":\"rgb(17,17,17)\",\"gridcolor\":\"#506784\",\"gridwidth\":2,\"linecolor\":\"#506784\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"#C8D4E3\"}},\"shapedefaults\":{\"line\":{\"color\":\"#f2f5fa\"}},\"sliderdefaults\":{\"bgcolor\":\"#C8D4E3\",\"bordercolor\":\"rgb(17,17,17)\",\"borderwidth\":1,\"tickwidth\":0},\"ternary\":{\"aaxis\":{\"gridcolor\":\"#506784\",\"linecolor\":\"#506784\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"#506784\",\"linecolor\":\"#506784\",\"ticks\":\"\"},\"bgcolor\":\"rgb(17,17,17)\",\"caxis\":{\"gridcolor\":\"#506784\",\"linecolor\":\"#506784\",\"ticks\":\"\"}},\"title\":{\"x\":0.05},\"updatemenudefaults\":{\"bgcolor\":\"#506784\",\"borderwidth\":0},\"xaxis\":{\"automargin\":true,\"gridcolor\":\"#283442\",\"linecolor\":\"#506784\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"#283442\",\"zerolinewidth\":2},\"yaxis\":{\"automargin\":true,\"gridcolor\":\"#283442\",\"linecolor\":\"#506784\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"#283442\",\"zerolinewidth\":2}}},\"xaxis\":{\"anchor\":\"y\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x3\",\"range\":[0,21],\"showgrid\":false,\"showticklabels\":false},\"xaxis2\":{\"anchor\":\"y2\",\"domain\":[0.0,1.0],\"dtick\":2,\"matches\":\"x\",\"range\":[0,21],\"showgrid\":false,\"showticklabels\":false},\"xaxis3\":{\"anchor\":\"y3\",\"domain\":[0.0,1.0],\"dtick\":2,\"showgrid\":false,\"title\":{\"text\":\"$\\\\mbox{Iteration Number}$\"}},\"yaxis\":{\"anchor\":\"x\",\"automargin\":true,\"domain\":[0.79,1.0],\"exponentformat\":\"e\",\"nticks\":4,\"tickformat\":\"g\",\"title\":{\"text\":\"$T_{\\\\text{inner}}\\\\ [\\\\text{K}]$\"}},\"yaxis2\":{\"anchor\":\"x2\",\"automargin\":true,\"domain\":[0.29,0.71],\"exponentformat\":\"e\",\"nticks\":7,\"title\":{\"font\":{\"size\":13},\"text\":\"$\\\\text{Luminosity}~[\\\\text{erg s}^{-1}]$\"}},\"yaxis3\":{\"anchor\":\"x3\",\"automargin\":true,\"domain\":[0.0,0.21],\"nticks\":4,\"title\":{\"font\":{\"size\":12},\"text\":\"$~~\\\\text{Residual}\\\\\\\\\\\\text{Luminosity[%]}$\"}}},                        {\"responsive\": true}                    ).then(function(){\n",
       "                            \n",
       "var gd = document.getElementById('6aa18f35-9b6f-4bc6-9bb1-8a7577d262a8');\n",
       "var x = new MutationObserver(function (mutations, observer) {{\n",
       "        var display = window.getComputedStyle(gd).display;\n",
       "        if (!display || display === 'none') {{\n",
       "            console.log([gd, 'removed!']);\n",
       "            Plotly.purge(gd);\n",
       "            observer.disconnect();\n",
       "        }}\n",
       "}});\n",
       "\n",
       "// Listen for the removal of the full notebook cells\n",
       "var notebookContainer = gd.closest('#notebook-container');\n",
       "if (notebookContainer) {{\n",
       "    x.observe(notebookContainer, {childList: true});\n",
       "}}\n",
       "\n",
       "// Listen for the clearing of the current output cell\n",
       "var outputEl = gd.closest('.output');\n",
       "if (outputEl) {{\n",
       "    x.observe(outputEl, {childList: true});\n",
       "}}\n",
       "\n",
       "                        })                };                });            </script>        </div>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "sim = run_tardis(\n",
    "    \"tardis_example.yml\",\n",
    "    plasma_plot_config={\n",
    "        \"layout\": {\n",
    "            \"template\": \"ggplot2\",\n",
    "            \"xaxis1\": {\n",
    "                \"nticks\": 20\n",
    "            },\n",
    "            \"xaxis2\": {\n",
    "                \"title\": {\"text\": \"new changed title of x axis2\"},\n",
    "                \"nticks\": 20\n",
    "            },\n",
    "        },\n",
    "    },\n",
    "    t_inner_luminosities_config={\n",
    "        \"data\": {\n",
    "            \"line\":{\n",
    "                \"dash\":\"dot\"\n",
    "            },\n",
    "            \"mode\": \"lines+markers\",\n",
    "        },\n",
    "        \"layout\": {\n",
    "            \"template\": \"plotly_dark\",\n",
    "            \"hovermode\":\"x\",\n",
    "            \"xaxis\":{\"showgrid\":False},\n",
    "            \"xaxis2\":{\"showgrid\":False},\n",
    "            \"xaxis3\":{\"showgrid\":False},\n",
    "            \n",
    "        },\n",
    "    },\n",
    "    export_convergence_plots = True)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "6ceaaa1e",
   "metadata": {
    "execution": {
     "iopub.execute_input": "2021-10-14T16:52:08.663731Z",
     "iopub.status.busy": "2021-10-14T16:52:08.663084Z",
     "iopub.status.idle": "2021-10-14T16:52:08.665449Z",
     "shell.execute_reply": "2021-10-14T16:52:08.665942Z"
    },
    "scrolled": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Help on class ConvergencePlots in module tardis.visualization.tools.convergence_plot:\n",
      "\n",
      "class ConvergencePlots(builtins.object)\n",
      " |  ConvergencePlots(iterations, **kwargs)\n",
      " |  \n",
      " |  Create and update convergence plots for visualizing convergence of the simulation.\n",
      " |  \n",
      " |  Parameters\n",
      " |  ----------\n",
      " |  iterations : int\n",
      " |      iteration number\n",
      " |  **kwargs : dict, optional\n",
      " |      Additional keyword arguments. These arguments are defined in the Other Parameters section.\n",
      " |  \n",
      " |  Other Parameters\n",
      " |  ----------------\n",
      " |  plasma_plot_config : dict, optional\n",
      " |      Dictionary used to override default plot properties of plasma plots.\n",
      " |  t_inner_luminosities_config : dict, optional\n",
      " |      Dictionary used to override default plot properties of the inner boundary temperature and luminosity plots.\n",
      " |  plasma_cmap : str, default: 'jet', optional\n",
      " |      String defining the cmap used in plasma plots.\n",
      " |  t_inner_luminosities_colors : str or list, optional\n",
      " |      String defining cmap for luminosity and inner boundary temperature plot.\n",
      " |      The list can be a list of colors in rgb, hex or css-names format as well.\n",
      " |  export_convergence_plots : bool, default: False, optional\n",
      " |      If True, plots are displayed again using the `notebook_connected` renderer. This helps\n",
      " |      to display the plots in the documentation or in platforms like nbviewer.\n",
      " |  \n",
      " |  Notes\n",
      " |  -----\n",
      " |      When overriding plot's configuration using the `plasma_plot_config` and the\n",
      " |      `t_inner_luminosities_config` dictionaries, data related properties are\n",
      " |      applied equally accross all traces.\n",
      " |      The dictionary should have a structure like that of `plotly.graph_objs.FigureWidget.to_dict()`,\n",
      " |      for more information please see https://plotly.com/python/figure-structure/\n",
      " |  \n",
      " |  Methods defined here:\n",
      " |  \n",
      " |  __init__(self, iterations, **kwargs)\n",
      " |      Initialize self.  See help(type(self)) for accurate signature.\n",
      " |  \n",
      " |  build(self, display_plot=True)\n",
      " |      Create empty convergence plots and display them.\n",
      " |      \n",
      " |      Parameters\n",
      " |      ----------\n",
      " |      display_plot : bool, default: True, optional\n",
      " |          Displays empty plots.\n",
      " |  \n",
      " |  create_plasma_plot(self)\n",
      " |      Create an empty plasma plot.\n",
      " |  \n",
      " |  create_t_inner_luminosities_plot(self)\n",
      " |      Create an empty t_inner and luminosity plot.\n",
      " |  \n",
      " |  fetch_data(self, name=None, value=None, item_type=None)\n",
      " |      Fetch data from the Simulation class.\n",
      " |      \n",
      " |      Parameters\n",
      " |      ----------\n",
      " |      name : string\n",
      " |          name of the data\n",
      " |      value : string or array\n",
      " |          string or an array of quantities\n",
      " |      item_type : string\n",
      " |          either iterable or value\n",
      " |  \n",
      " |  override_plot_parameters(self, fig, parameters)\n",
      " |      Override default plot properties.\n",
      " |      \n",
      " |      Any property inside the data dictionary is however, applied equally across all traces.\n",
      " |      This means trace-specific data properties can't be changed using this function.\n",
      " |      \n",
      " |      Parameters\n",
      " |      ----------\n",
      " |      fig : go.FigureWidget\n",
      " |          FigureWidget object to be updated\n",
      " |      parameters : dict\n",
      " |          Dictionary used to update the default plot style.\n",
      " |  \n",
      " |  update(self, export_convergence_plots=False, last=False)\n",
      " |      Update the convergence plots every iteration.\n",
      " |      \n",
      " |      Parameters\n",
      " |      ----------\n",
      " |      export_convergence_plots : bool, default: False, optional\n",
      " |          Displays the convergence plots again using plotly's `notebook_connected` renderer.\n",
      " |          This helps to display the plots in notebooks when shared on platforms like nbviewer.\n",
      " |          Please see https://plotly.com/python/renderers/ for more information.\n",
      " |      last : bool, default: False, optional\n",
      " |          True if it's last iteration.\n",
      " |  \n",
      " |  update_plasma_plots(self)\n",
      " |      Update plasma convergence plots every iteration.\n",
      " |  \n",
      " |  update_t_inner_luminosities_plot(self)\n",
      " |      Update the t_inner and luminosity convergence plots every iteration.\n",
      " |  \n",
      " |  ----------------------------------------------------------------------\n",
      " |  Data descriptors defined here:\n",
      " |  \n",
      " |  __dict__\n",
      " |      dictionary for instance variables (if defined)\n",
      " |  \n",
      " |  __weakref__\n",
      " |      list of weak references to the object (if defined)\n",
      "\n"
     ]
    }
   ],
   "source": [
    "from tardis.visualization import ConvergencePlots\n",
    "help(ConvergencePlots)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.10"
  },
  "widgets": {
   "application/vnd.jupyter.widget-state+json": {
    "state": {
     "02f57efb852947da93aaab9fa4d8a506": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "061a4a0238d44d6295c0382306adfbdd": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_7345e372e047477088453fc4005ba8c6",
       "max": 20.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_cc329cc1df104fd38a78e7a0be3c5d09",
       "value": 20.0
      }
     },
     "073c0a951e154d24aaae74caeda28a3a": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "0a1ec4f60b7d4f90a31d1dafeb5341b0": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "0b031b2ee5404fc1a02ccaa15214981d": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "0bd63811a2f5469fb98a968d2ade389a": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "0dea7b83e75d43f8bcc3963e375f9d0a": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "11964e1c2f9f42a2b6813069a637ea02": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "1282bd35cbcb4833babad66b02bc7d3a": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_19865850781b4fea9cd19c1158c0ff3c",
       "placeholder": "​",
       "style": "IPY_MODEL_8d4499456c3a471d996f1882a4c6ab93",
       "value": "Packets:   "
      }
     },
     "14472aba1017430bb0b7a31618d6aa00": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "1751af946a894f86b29de4b77229670f": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "6%"
      }
     },
     "18b4ebb9c95d4b5087d0d0d736fc9467": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "19865850781b4fea9cd19c1158c0ff3c": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "6%"
      }
     },
     "1b17fe279d7e42619a3a61db6e7d2401": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_68f1a4d5299041beb28adc01c56ee9a9",
       "placeholder": "​",
       "style": "IPY_MODEL_f212f222c184486ead26e8d39f13ca0f",
       "value": "Packets:   "
      }
     },
     "22656b3c157a43d59475336d4a7e5589": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_0bd63811a2f5469fb98a968d2ade389a",
       "placeholder": "​",
       "style": "IPY_MODEL_18b4ebb9c95d4b5087d0d0d736fc9467",
       "value": "0/? [00:00&lt;?, ?it/s]"
      }
     },
     "26c57d3c08f64c0eb077be64750e9f3c": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "2743de4a3a4b4435b83b763ed0ee021a": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "60%"
      }
     },
     "2770d2033a4e4af78a40e4e93bf3561d": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_2743de4a3a4b4435b83b763ed0ee021a",
       "max": 20.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_4ec0acb4d09e4d1db72fd68c187e1191",
       "value": 20.0
      }
     },
     "2818fb4441694492bf0811ff76d0ed15": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "2b042d8d59c34cbdac5e8f65ae03effe": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "60%"
      }
     },
     "2d71663b0a974953a09e4d7545c735de": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_2fe3eff8a8ff48d2bed3950c7e7d2fd1",
        "IPY_MODEL_b678eb116cfc477dbfe6333f9a37ba51",
        "IPY_MODEL_dcd19252514d461884f1900d982745d5"
       ],
       "layout": "IPY_MODEL_6ddf8fcb67734cea844a4b55ffcb3a9f"
      }
     },
     "2fe3eff8a8ff48d2bed3950c7e7d2fd1": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_1751af946a894f86b29de4b77229670f",
       "placeholder": "​",
       "style": "IPY_MODEL_3b32422060f44763978933464fa3e1b3",
       "value": "Iterations:"
      }
     },
     "32bfd85f98fe4c22928a34a0b9e9f5c7": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_437493753fca4a6baec7565b5d4e919f",
       "placeholder": "​",
       "style": "IPY_MODEL_2818fb4441694492bf0811ff76d0ed15",
       "value": "99533/100000 [00:14&lt;00:00, 7133.69it/s]"
      }
     },
     "3389fa638eae4aff9584e29127e3fa2a": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_908bb40a12104ac89f082988c0ea6f84",
       "placeholder": "​",
       "style": "IPY_MODEL_0a1ec4f60b7d4f90a31d1dafeb5341b0",
       "value": "20/20 [00:33&lt;00:00,  5.04s/it]"
      }
     },
     "34b378ff483e4eab8245110161d422a0": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_9a11cc6a60a84fefaca0468f71465919",
        "IPY_MODEL_eea1228da9d54fc7b27e047b2eacb835",
        "IPY_MODEL_4027bd3fb8bd42df8948565ac61c3888"
       ],
       "layout": "IPY_MODEL_b96be1a48e8b44eb94841f31961b2656"
      }
     },
     "3b32422060f44763978933464fa3e1b3": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "3d34eb50f77c4b89acdea0cede9e51ad": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "3de73faeedfb45258d3c41d9112fc346": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_4bd1d4e0f7064436b3d0de86ca0a6fa8",
       "placeholder": "​",
       "style": "IPY_MODEL_fd214c177bfd4335874ffe89cb4eec62",
       "value": "99705/100000 [00:14&lt;00:00, 7037.37it/s]"
      }
     },
     "4027bd3fb8bd42df8948565ac61c3888": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_02f57efb852947da93aaab9fa4d8a506",
       "placeholder": "​",
       "style": "IPY_MODEL_ec0d7831232945278f28485e3c982454",
       "value": "99519/100000 [00:14&lt;00:00, 7034.96it/s]"
      }
     },
     "429544d24c7846d8855fea6728dc6ef7": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_c8105a42bbb64ec4926860d2bd515f38",
       "max": 100000.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_a54680b41d084717afc8fad7c50ea894",
       "value": 99533.0
      }
     },
     "437493753fca4a6baec7565b5d4e919f": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "4ac61ab6a7b34790ada783e9e259a288": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "4bd1d4e0f7064436b3d0de86ca0a6fa8": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "4c8a8ad1a6554a8299813dacf1f1fafc": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_4ac61ab6a7b34790ada783e9e259a288",
       "placeholder": "​",
       "style": "IPY_MODEL_ccbda8cb0b13447aabad4eba7221bd1b",
       "value": "Iterations:"
      }
     },
     "4ec0acb4d09e4d1db72fd68c187e1191": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "5344502de3d141dabc1b11b041ad0246": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "582f4ee7d99b47e6bd29a7c505a6a264": {
      "buffers": [
       {
        "data": "iz+pjrWx3T+GdSFoWsLWP4dq5J5mW9I/1NCULSM8zj/jpCBw6mDKPxfKu/ExpcY/7s/dnStcxD9u9oXGBS7CPxd8klk13cA/rOarH2RDvz//HRqqIu68P4051toA9ro/I8sPSIFjuT+a8VK8PL63P83Gz/vaxrY/+G8p1sq0tT9RwNxSaNO0P6+MX5zxALQ/7qHwURoOsz+XInGBQ7KyPw==",
        "encoding": "base64",
        "path": [
         "_py2js_addTraces",
         "trace_data",
         0,
         "y",
         "buffer"
        ]
       }
      ],
      "model_module": "jupyterlab-plotly",
      "model_module_version": "^5.3.1",
      "model_name": "FigureModel",
      "state": {
       "_config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "_data": [],
       "_dom_classes": [],
       "_js2py_layoutDelta": {},
       "_js2py_pointsCallback": {},
       "_js2py_relayout": {},
       "_js2py_restyle": {},
       "_js2py_traceDeltas": {},
       "_js2py_update": {},
       "_last_layout_edit_id": 44,
       "_last_trace_edit_id": 44,
       "_layout": {},
       "_model_module": "jupyterlab-plotly",
       "_model_module_version": "^5.3.1",
       "_model_name": "FigureModel",
       "_py2js_addTraces": null,
       "_py2js_animate": {},
       "_py2js_deleteTraces": {},
       "_py2js_moveTraces": {},
       "_py2js_relayout": null,
       "_py2js_removeLayoutProps": {},
       "_py2js_removeTraceProps": {},
       "_py2js_restyle": {},
       "_py2js_update": null,
       "_view_count": 0,
       "_view_module": "jupyterlab-plotly",
       "_view_module_version": "^5.3.1",
       "_view_name": "FigureView"
      }
     },
     "5899a549ffc84f3381b4e3a747850d17": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_4c8a8ad1a6554a8299813dacf1f1fafc",
        "IPY_MODEL_95009ccc393b42e1958d7bea7809a542",
        "IPY_MODEL_22656b3c157a43d59475336d4a7e5589"
       ],
       "layout": "IPY_MODEL_11964e1c2f9f42a2b6813069a637ea02"
      }
     },
     "664b662cfe7a4c428e155e2c5fb43cc5": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "66ffc286b52f4aef97e62c2dc6a35f28": {
      "buffers": [
       {
        "data": "iz+pjrWx3T+GdSFoWsLWP4dq5J5mW9I/1NCULSM8zj/jpCBw6mDKPxfKu/ExpcY/7s/dnStcxD9u9oXGBS7CPxd8klk13cA/rOarH2RDvz//HRqqIu68P4051toA9ro/I8sPSIFjuT+a8VK8PL63P83Gz/vaxrY/+G8p1sq0tT9RwNxSaNO0P6+MX5zxALQ/7qHwURoOsz+XInGBQ7KyPw==",
        "encoding": "base64",
        "path": [
         "_py2js_addTraces",
         "trace_data",
         0,
         "y",
         "buffer"
        ]
       }
      ],
      "model_module": "jupyterlab-plotly",
      "model_module_version": "^5.3.1",
      "model_name": "FigureModel",
      "state": {
       "_config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "_data": [],
       "_dom_classes": [],
       "_js2py_layoutDelta": {},
       "_js2py_pointsCallback": {},
       "_js2py_relayout": {},
       "_js2py_restyle": {},
       "_js2py_traceDeltas": {},
       "_js2py_update": {},
       "_last_layout_edit_id": 48,
       "_last_trace_edit_id": 44,
       "_layout": {},
       "_model_module": "jupyterlab-plotly",
       "_model_module_version": "^5.3.1",
       "_model_name": "FigureModel",
       "_py2js_addTraces": null,
       "_py2js_animate": {},
       "_py2js_deleteTraces": {},
       "_py2js_moveTraces": {},
       "_py2js_relayout": null,
       "_py2js_removeLayoutProps": {},
       "_py2js_removeTraceProps": {},
       "_py2js_restyle": {},
       "_py2js_update": null,
       "_view_count": 0,
       "_view_module": "jupyterlab-plotly",
       "_view_module_version": "^5.3.1",
       "_view_name": "FigureView"
      }
     },
     "677bb7955f8c43b0be4ca48151024817": {
      "model_module": "jupyterlab-plotly",
      "model_module_version": "^5.3.1",
      "model_name": "FigureModel",
      "state": {
       "_config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "_data": [],
       "_dom_classes": [],
       "_js2py_layoutDelta": {},
       "_js2py_pointsCallback": {},
       "_js2py_relayout": {},
       "_js2py_restyle": {},
       "_js2py_traceDeltas": {},
       "_js2py_update": {},
       "_last_layout_edit_id": 27,
       "_last_trace_edit_id": 27,
       "_layout": {},
       "_model_module": "jupyterlab-plotly",
       "_model_module_version": "^5.3.1",
       "_model_name": "FigureModel",
       "_py2js_addTraces": null,
       "_py2js_animate": {},
       "_py2js_deleteTraces": {},
       "_py2js_moveTraces": {},
       "_py2js_relayout": null,
       "_py2js_removeLayoutProps": {},
       "_py2js_removeTraceProps": {},
       "_py2js_restyle": {},
       "_py2js_update": null,
       "_view_count": 0,
       "_view_module": "jupyterlab-plotly",
       "_view_module_version": "^5.3.1",
       "_view_name": "FigureView"
      }
     },
     "68f1a4d5299041beb28adc01c56ee9a9": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "6ddf8fcb67734cea844a4b55ffcb3a9f": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "7345e372e047477088453fc4005ba8c6": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "60%"
      }
     },
     "79b1e3d9ffc14e94bdf3435e21a89f5d": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "6%"
      }
     },
     "7dd9b02611ee4ec2ac4465c65089860c": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "8600478828254d2cbe91bf54663975e3": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_8d8b7d53faee4088888f5280522a639a",
       "placeholder": "​",
       "style": "IPY_MODEL_5344502de3d141dabc1b11b041ad0246",
       "value": "Iterations:"
      }
     },
     "860d74c30a064eb5a02c45c54aca816a": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "8d4499456c3a471d996f1882a4c6ab93": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "8d8377048ee740cb8079f018deade1dd": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "8d8b7d53faee4088888f5280522a639a": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "6%"
      }
     },
     "8e994a476762493c813bb5e93a3c9031": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "8fe328d8aee64e4698cc78a01047fea8": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "908bb40a12104ac89f082988c0ea6f84": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "90a25bd73fd344959b3181837445b491": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "95009ccc393b42e1958d7bea7809a542": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "info",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_e63de77f777a4aa692e685d6b1f58d7b",
       "max": 1.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_8d8377048ee740cb8079f018deade1dd",
       "value": 0.0
      }
     },
     "9a11cc6a60a84fefaca0468f71465919": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_e37d9af99f3e4d258ecd20ae124ccec7",
       "placeholder": "​",
       "style": "IPY_MODEL_8fe328d8aee64e4698cc78a01047fea8",
       "value": "Packets:   "
      }
     },
     "9c61b28dcbd94faaa0666f457fb777d8": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "a3fc81550f5141b39f1a03d2995a592b": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "60%"
      }
     },
     "a54680b41d084717afc8fad7c50ea894": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "a6fe7e53dd9c49779f555e9591f32b35": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "20px"
      }
     },
     "a948233639374a068eae4b555c318536": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "ac1e8e03bac141eab840b004f6abf68d": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_b7280ef9f51444ecb3688ea2c94a9127",
       "placeholder": "​",
       "style": "IPY_MODEL_9c61b28dcbd94faaa0666f457fb777d8",
       "value": "20/20 [00:33&lt;00:00,  5.12s/it]"
      }
     },
     "ac46524d327546c7a3dde2debd4371e0": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "acdd5728f6cc4c3f9cc13dceb0247614": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "add27241ccfd4c3ebbd4cbb87c30c944": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "aed6a826fa7a4d21a359a4787b0f7a10": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "info",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_a6fe7e53dd9c49779f555e9591f32b35",
       "max": 1.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_90a25bd73fd344959b3181837445b491",
       "value": 0.0
      }
     },
     "b1f30d977de141c4a6382811e92e08d1": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "b5d5723c3d444ce2952f8637ecffdd99": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_79b1e3d9ffc14e94bdf3435e21a89f5d",
       "placeholder": "​",
       "style": "IPY_MODEL_b1f30d977de141c4a6382811e92e08d1",
       "value": "Packets:   "
      }
     },
     "b678eb116cfc477dbfe6333f9a37ba51": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_e0bdf4d78def44e483ed81698dc56d03",
       "max": 20.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_0dea7b83e75d43f8bcc3963e375f9d0a",
       "value": 20.0
      }
     },
     "b6da0dc359b94da29613187eb419ea70": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "VBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "VBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "VBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_d8ca7924750a4a00aa50c34aa9bb7eda",
        "IPY_MODEL_e3eb9fc3540346b0b56447be70ad7726"
       ],
       "layout": "IPY_MODEL_14472aba1017430bb0b7a31618d6aa00"
      }
     },
     "b7280ef9f51444ecb3688ea2c94a9127": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "b96be1a48e8b44eb94841f31961b2656": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "c28ba22c99ff40baa1019a408a8846c4": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_1b17fe279d7e42619a3a61db6e7d2401",
        "IPY_MODEL_aed6a826fa7a4d21a359a4787b0f7a10",
        "IPY_MODEL_f15e68238a8e4210ba18ad4a0f08864f"
       ],
       "layout": "IPY_MODEL_8e994a476762493c813bb5e93a3c9031"
      }
     },
     "c2af2102055145bc854ff6378ca89640": {
      "model_module": "@jupyter-widgets/output",
      "model_module_version": "1.0.0",
      "model_name": "OutputModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/output",
       "_model_module_version": "1.0.0",
       "_model_name": "OutputModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/output",
       "_view_module_version": "1.0.0",
       "_view_name": "OutputView",
       "layout": "IPY_MODEL_3d34eb50f77c4b89acdea0cede9e51ad",
       "msg_id": "",
       "outputs": []
      }
     },
     "c488360869064c4b96385279c3b25f9d": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "c8105a42bbb64ec4926860d2bd515f38": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "60%"
      }
     },
     "cc329cc1df104fd38a78e7a0be3c5d09": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "ccbda8cb0b13447aabad4eba7221bd1b": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "d401a25f470d4136a349638cd50685c8": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "VBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "VBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "VBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_582f4ee7d99b47e6bd29a7c505a6a264",
        "IPY_MODEL_677bb7955f8c43b0be4ca48151024817"
       ],
       "layout": "IPY_MODEL_acdd5728f6cc4c3f9cc13dceb0247614"
      }
     },
     "d45c31175c6d4d55a4a1ecdad2fe64ba": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_b5d5723c3d444ce2952f8637ecffdd99",
        "IPY_MODEL_429544d24c7846d8855fea6728dc6ef7",
        "IPY_MODEL_32bfd85f98fe4c22928a34a0b9e9f5c7"
       ],
       "layout": "IPY_MODEL_ac46524d327546c7a3dde2debd4371e0"
      }
     },
     "d83e3b2a46824bda94baf365356d8088": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_fb5b53738c8e4fa39c7346760f5dc8a0",
       "placeholder": "​",
       "style": "IPY_MODEL_e4c0fcf102334a708dde594d17b78592",
       "value": "Iterations:"
      }
     },
     "d8ca7924750a4a00aa50c34aa9bb7eda": {
      "buffers": [
       {
        "data": "iz+pjrWx3T+GdSFoWsLWP4dq5J5mW9I/1NCULSM8zj/jpCBw6mDKPxfKu/ExpcY/7s/dnStcxD9u9oXGBS7CPxd8klk13cA/rOarH2RDvz//HRqqIu68P4051toA9ro/I8sPSIFjuT+a8VK8PL63P83Gz/vaxrY/+G8p1sq0tT9RwNxSaNO0P6+MX5zxALQ/7qHwURoOsz+XInGBQ7KyPw==",
        "encoding": "base64",
        "path": [
         "_py2js_addTraces",
         "trace_data",
         0,
         "y",
         "buffer"
        ]
       }
      ],
      "model_module": "jupyterlab-plotly",
      "model_module_version": "^5.3.1",
      "model_name": "FigureModel",
      "state": {
       "_config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "_data": [],
       "_dom_classes": [],
       "_js2py_layoutDelta": {},
       "_js2py_pointsCallback": {},
       "_js2py_relayout": {},
       "_js2py_restyle": {},
       "_js2py_traceDeltas": {},
       "_js2py_update": {},
       "_last_layout_edit_id": 44,
       "_last_trace_edit_id": 44,
       "_layout": {},
       "_model_module": "jupyterlab-plotly",
       "_model_module_version": "^5.3.1",
       "_model_name": "FigureModel",
       "_py2js_addTraces": null,
       "_py2js_animate": {},
       "_py2js_deleteTraces": {},
       "_py2js_moveTraces": {},
       "_py2js_relayout": null,
       "_py2js_removeLayoutProps": {},
       "_py2js_removeTraceProps": {},
       "_py2js_restyle": {},
       "_py2js_update": null,
       "_view_count": 0,
       "_view_module": "jupyterlab-plotly",
       "_view_module_version": "^5.3.1",
       "_view_name": "FigureView"
      }
     },
     "dc6c9c724d4b413bbf3da367eccae4ba": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_d83e3b2a46824bda94baf365356d8088",
        "IPY_MODEL_2770d2033a4e4af78a40e4e93bf3561d",
        "IPY_MODEL_3389fa638eae4aff9584e29127e3fa2a"
       ],
       "layout": "IPY_MODEL_0b031b2ee5404fc1a02ccaa15214981d"
      }
     },
     "dcd19252514d461884f1900d982745d5": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_26c57d3c08f64c0eb077be64750e9f3c",
       "placeholder": "​",
       "style": "IPY_MODEL_add27241ccfd4c3ebbd4cbb87c30c944",
       "value": "20/20 [00:34&lt;00:00,  5.12s/it]"
      }
     },
     "e0bdf4d78def44e483ed81698dc56d03": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "60%"
      }
     },
     "e1c0a4c8e5ce4fe9aa6ef8e01fb8b819": {
      "model_module": "jupyterlab-plotly",
      "model_module_version": "^5.3.1",
      "model_name": "FigureModel",
      "state": {
       "_config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "_data": [],
       "_dom_classes": [],
       "_js2py_layoutDelta": {},
       "_js2py_pointsCallback": {},
       "_js2py_relayout": {},
       "_js2py_restyle": {},
       "_js2py_traceDeltas": {},
       "_js2py_update": {},
       "_last_layout_edit_id": 42,
       "_last_trace_edit_id": 37,
       "_layout": {},
       "_model_module": "jupyterlab-plotly",
       "_model_module_version": "^5.3.1",
       "_model_name": "FigureModel",
       "_py2js_addTraces": null,
       "_py2js_animate": {},
       "_py2js_deleteTraces": {},
       "_py2js_moveTraces": {},
       "_py2js_relayout": null,
       "_py2js_removeLayoutProps": {},
       "_py2js_removeTraceProps": {},
       "_py2js_restyle": null,
       "_py2js_update": null,
       "_view_count": 0,
       "_view_module": "jupyterlab-plotly",
       "_view_module_version": "^5.3.1",
       "_view_name": "FigureView"
      }
     },
     "e2160d425e4e4cda84e4434de712658a": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": null
      }
     },
     "e37d9af99f3e4d258ecd20ae124ccec7": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "6%"
      }
     },
     "e3eb9fc3540346b0b56447be70ad7726": {
      "model_module": "jupyterlab-plotly",
      "model_module_version": "^5.3.1",
      "model_name": "FigureModel",
      "state": {
       "_config": {
        "plotlyServerURL": "https://plot.ly"
       },
       "_data": [],
       "_dom_classes": [],
       "_js2py_layoutDelta": {},
       "_js2py_pointsCallback": {},
       "_js2py_relayout": {},
       "_js2py_restyle": {},
       "_js2py_traceDeltas": {},
       "_js2py_update": {},
       "_last_layout_edit_id": 27,
       "_last_trace_edit_id": 27,
       "_layout": {},
       "_model_module": "jupyterlab-plotly",
       "_model_module_version": "^5.3.1",
       "_model_name": "FigureModel",
       "_py2js_addTraces": null,
       "_py2js_animate": {},
       "_py2js_deleteTraces": {},
       "_py2js_moveTraces": {},
       "_py2js_relayout": null,
       "_py2js_removeLayoutProps": {},
       "_py2js_removeTraceProps": {},
       "_py2js_restyle": {},
       "_py2js_update": null,
       "_view_count": 0,
       "_view_module": "jupyterlab-plotly",
       "_view_module_version": "^5.3.1",
       "_view_name": "FigureView"
      }
     },
     "e4c0fcf102334a708dde594d17b78592": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "e63de77f777a4aa692e685d6b1f58d7b": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "20px"
      }
     },
     "ec0d7831232945278f28485e3c982454": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "ec438fca490341948efa8b4b33ef1b9f": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "VBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "VBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "VBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_66ffc286b52f4aef97e62c2dc6a35f28",
        "IPY_MODEL_e1c0a4c8e5ce4fe9aa6ef8e01fb8b819"
       ],
       "layout": "IPY_MODEL_860d74c30a064eb5a02c45c54aca816a"
      }
     },
     "ed19815c9c5044918ac54f5511783598": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_2b042d8d59c34cbdac5e8f65ae03effe",
       "max": 100000.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_fa782e27545642c88111140eec9b4b9b",
       "value": 99705.0
      }
     },
     "eea1228da9d54fc7b27e047b2eacb835": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "FloatProgressModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "FloatProgressModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "ProgressView",
       "bar_style": "",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_a3fc81550f5141b39f1a03d2995a592b",
       "max": 100000.0,
       "min": 0.0,
       "orientation": "horizontal",
       "style": "IPY_MODEL_664b662cfe7a4c428e155e2c5fb43cc5",
       "value": 99519.0
      }
     },
     "f13b949f6bb14150bd3306106bcbeb2d": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_1282bd35cbcb4833babad66b02bc7d3a",
        "IPY_MODEL_ed19815c9c5044918ac54f5511783598",
        "IPY_MODEL_3de73faeedfb45258d3c41d9112fc346"
       ],
       "layout": "IPY_MODEL_c488360869064c4b96385279c3b25f9d"
      }
     },
     "f15e68238a8e4210ba18ad4a0f08864f": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HTMLModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HTMLModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HTMLView",
       "description": "",
       "description_tooltip": null,
       "layout": "IPY_MODEL_a948233639374a068eae4b555c318536",
       "placeholder": "​",
       "style": "IPY_MODEL_073c0a951e154d24aaae74caeda28a3a",
       "value": "0/? [00:00&lt;?, ?it/s]"
      }
     },
     "f212f222c184486ead26e8d39f13ca0f": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     },
     "f4b60f775adf4eb99a73beb241d0868a": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "HBoxModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "HBoxModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/controls",
       "_view_module_version": "1.5.0",
       "_view_name": "HBoxView",
       "box_style": "",
       "children": [
        "IPY_MODEL_8600478828254d2cbe91bf54663975e3",
        "IPY_MODEL_061a4a0238d44d6295c0382306adfbdd",
        "IPY_MODEL_ac1e8e03bac141eab840b004f6abf68d"
       ],
       "layout": "IPY_MODEL_e2160d425e4e4cda84e4434de712658a"
      }
     },
     "f86fb7a6dd464dd4a15e0f09bc40a0fe": {
      "model_module": "@jupyter-widgets/output",
      "model_module_version": "1.0.0",
      "model_name": "OutputModel",
      "state": {
       "_dom_classes": [],
       "_model_module": "@jupyter-widgets/output",
       "_model_module_version": "1.0.0",
       "_model_name": "OutputModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/output",
       "_view_module_version": "1.0.0",
       "_view_name": "OutputView",
       "layout": "IPY_MODEL_7dd9b02611ee4ec2ac4465c65089860c",
       "msg_id": "",
       "outputs": []
      }
     },
     "fa782e27545642c88111140eec9b4b9b": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "ProgressStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "ProgressStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "bar_color": null,
       "description_width": ""
      }
     },
     "fb5b53738c8e4fa39c7346760f5dc8a0": {
      "model_module": "@jupyter-widgets/base",
      "model_module_version": "1.2.0",
      "model_name": "LayoutModel",
      "state": {
       "_model_module": "@jupyter-widgets/base",
       "_model_module_version": "1.2.0",
       "_model_name": "LayoutModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "LayoutView",
       "align_content": null,
       "align_items": null,
       "align_self": null,
       "border": null,
       "bottom": null,
       "display": null,
       "flex": null,
       "flex_flow": null,
       "grid_area": null,
       "grid_auto_columns": null,
       "grid_auto_flow": null,
       "grid_auto_rows": null,
       "grid_column": null,
       "grid_gap": null,
       "grid_row": null,
       "grid_template_areas": null,
       "grid_template_columns": null,
       "grid_template_rows": null,
       "height": null,
       "justify_content": null,
       "justify_items": null,
       "left": null,
       "margin": null,
       "max_height": null,
       "max_width": null,
       "min_height": null,
       "min_width": null,
       "object_fit": null,
       "object_position": null,
       "order": null,
       "overflow": null,
       "overflow_x": null,
       "overflow_y": null,
       "padding": null,
       "right": null,
       "top": null,
       "visibility": null,
       "width": "6%"
      }
     },
     "fd214c177bfd4335874ffe89cb4eec62": {
      "model_module": "@jupyter-widgets/controls",
      "model_module_version": "1.5.0",
      "model_name": "DescriptionStyleModel",
      "state": {
       "_model_module": "@jupyter-widgets/controls",
       "_model_module_version": "1.5.0",
       "_model_name": "DescriptionStyleModel",
       "_view_count": null,
       "_view_module": "@jupyter-widgets/base",
       "_view_module_version": "1.2.0",
       "_view_name": "StyleView",
       "description_width": ""
      }
     }
    },
    "version_major": 2,
    "version_minor": 0
   }
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
